@@ -34,9 +34,9 @@ typedef struct ms_info
 void init_msequence();
 void ms_loop();
 void ms_loop_proc();
-//int ms_do(int (*func)(void*), void * arg,int, char str[]);
+int ms_do(int (*func)(void*), void * arg,int, char str[]);
 int get_userinterface_tid();
-
+void er_panic(char*);
 
 #endif
 
