@@ -44,6 +44,9 @@ typedef struct _sem {
 	char *		unlock_file;
 	int		unlock_line;
 	HTID		unlock_htid;
+	
+	char *		create_file;
+	int		create_line;
 } _SEM;
 
 #endif
