@@ -104,8 +104,10 @@ int _mode;
 int _equ;
 int _no;
 	cw = get_env_work(env);
-	if ( cw == 0 )
+	if ( cw == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	mtx = cw->mtx;
 	no = get_sf_attribute(sf,l_string(std_cm,"area"));
 	if ( no == 0 ) {
@@ -238,8 +240,10 @@ int int_p;
 L_CHAR * channel;
 INTEGER64 long_p;
 	cw = get_env_work(env);
-	if ( cw == 0 )
+	if ( cw == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	mtx = cw->mtx;
 	if ( cw->mode != MXEM_CREATE )
 		return 0;
@@ -414,8 +418,10 @@ L_CHAR * dim;
 char * e_msg;
 int er;
 	cw = get_env_work(env);
-	if ( cw == 0 )
+	if ( cw == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	mtx = cw->mtx;
 	if ( cw->mode != MXEM_CREATE )
 		return 0;
@@ -467,8 +473,10 @@ L_CHAR * dim;
 char * e_msg;
 int er;
 	cw = get_env_work(env);
-	if ( cw == 0 )
+	if ( cw == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	mtx = cw->mtx;
 	if ( cw->mode != MXEM_CREATE )
 		return 0;
@@ -521,8 +529,10 @@ L_CHAR * dim;
 char * e_msg;
 int er;
 	cw = get_env_work(env);
-	if ( cw == 0 )
+	if ( cw == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	mtx = cw->mtx;
 	if ( cw->mode != MXEM_CREATE )
 		return 0;
@@ -576,9 +586,11 @@ char* e_msg;
 MATRIX_PARAM_WORK * w;
 MATRIX_PARAM * p;
 CREATE_WORK * cw;
-	w = get_env_work(env);
-	if ( w == 0 )
+        w = get_env_work(env);
+	if ( w == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	p = &w->p;
 	cw = w->cw;
 	area = get_sf_attribute(sf,l_string(std_cm,"area"));
@@ -648,8 +660,10 @@ L_CHAR * flags;
 CREATE_WORK * cw;
 
 	cw = get_env_work(env);
-	if ( cw == 0 )
+	if ( cw == 0 ) {
+		e_msg = "invalid emvironment use of gmx function"; 
 		goto inv_format;
+	}
 	mtx = cw->mtx;
 ss_printf("CW %p %i\n",cw,cw->mode);
 	if ( cw->mode != MXEM_CREATE )
