@@ -64,39 +64,38 @@ void _start_rs_write();
 void _end_rs_write();
 
 
-int change_endian_rs_res_status();
-int change_endian_rs_res_status();
-int change_endian_rs_coordinate_to_host();
-int change_endian_rs_coordinate_to_net();
-int change_endian_rs_pixel_map_r64_to_host();
-int change_endian_rs_pixel_map_r64_to_net();
-int change_endian_rs_draw_gb_to_host();
-int change_endian_rs_draw_gb_to_net();
-int change_endian_rs_res_map_to_host();
-int change_endian_rs_res_map_to_net();
-int change_endian_rs_bib_list_to_host();
-int change_endian_rs_bib_list_to_net();
-int change_endian_rs_note_to_host();
-int change_endian_rs_note_to_net();
-int change_endian_rs_clip_to_host();
-int change_endian_rs_clip_to_net();
-int change_endian_rs_map_to_host();
-int change_endian_rs_map_to_net();
-int change_endian_rs_info_scheme_to_host();
-int change_endian_rs_info_scheme_to_net();
-int change_endian_rs_triangle_to_host();
-int change_endian_rs_triangle_to_net();
-int change_endian_rs_map_point_list_to_host();
-int change_endian_rs_map_point_list_to_net();
-int change_endian_header_int();
+int change_endian_rs_res_status(PN_RS_RES_STATUS * st);
+int change_endian_rs_coordinate_to_host(PN_RS_COORDINATE * c);
+int change_endian_rs_coordinate_to_net(PN_RS_COORDINATE * c);
+int change_endian_rs_pixel_map_r64_to_host(PN_RS_PIXEL_MAP_R64 * r);
+int change_endian_rs_pixel_map_r64_to_net(PN_RS_PIXEL_MAP_R64 * r);
+int change_endian_rs_draw_gb_to_host(PN_RS_DRAW_GB * g);
+int change_endian_rs_draw_gb_to_net(PN_RS_DRAW_GB * g);
+int change_endian_rs_res_map_to_host(PN_RS_RES_MAP * m);
+int change_endian_rs_res_map_to_net(PN_RS_RES_MAP * m);
+int change_endian_rs_bib_list_to_host(PN_RS_BIB_LIST * b);
+int change_endian_rs_bib_list_to_net(PN_RS_BIB_LIST * b);
+int change_endian_rs_note_to_host(PN_RS_NOTE * n);
+int change_endian_rs_note_to_net(PN_RS_NOTE * n);
+int change_endian_rs_clip_to_host(PN_RS_CLIP * c);
+int change_endian_rs_clip_to_net(PN_RS_CLIP * c);
+int change_endian_rs_map_to_host(PN_RS_MAP * m);
+int change_endian_rs_map_to_net(PN_RS_MAP * m);
+int change_endian_rs_info_scheme_to_host(PN_RS_INFO_SCHEME * s);
+int change_endian_rs_info_scheme_to_net(PN_RS_INFO_SCHEME * s);
+int change_endian_rs_triangle_to_host(PN_RS_TRIANGLE * t);
+int change_endian_rs_triangle_to_net(PN_RS_TRIANGLE * t);
+int change_endian_rs_map_point_list_to_host(PN_RS_MAP_POINT_LIST * p);
+int change_endian_rs_map_point_list_to_net(PN_RS_MAP_POINT_LIST * p);
+int change_endian_header_int(PN_HEADER * h);
 
-int chain_string_all_to_host();
-int chain_rs_coordinate_to_host();
+int chain_string_all_to_host(RECORD_LIST * r);
+int chain_rs_coordinate_to_host(RECORD_LIST * r);
 
-RESOURCE * resource_rs_coordinate_to_host();
-RESOURCE * resource_rs_pixel_map_r64_to_host();
-RESOURCE * resource_rs_res_map_to_host();
-RESOURCE * resource_rs_draw_gb_to_host();
+RESOURCE * resource_rs_coordinate_to_host(RECORD_LIST * lst,RS_BUF * b);
+RESOURCE * resource_rs_pixel_map_r64_to_host(RECORD_LIST * lst,RS_BUF * b);
+RESOURCE * resource_rs_res_map_to_host(RECORD_LIST * lst,RS_BUF * w);
+RESOURCE * resource_rs_draw_gb_to_host(RECORD_LIST * lst,RS_BUF * );
 
 void change_endian_rs_cache_header(PN_RS_CACHE_HEADER * d);
 int change_endian_rs_cache_data_to_host(PN_RS_CACHE_DATA * d);
@@ -1538,7 +1537,7 @@ get_xl_sexp_from_string(L_CHAR * str)
 STREAM * s;
 XL_SEXP * ret, * load;
 
-	s = s_open_string_read(str,&int_cm,
+	s = s_open_string_read(str,&extucs4_cm,
 		(l_strlen(str)+1)*sizeof(L_CHAR),
 		1);
 	ret = car(load = 
@@ -1758,7 +1757,7 @@ err:
 }
 
 RESOURCE *
-resource_rs_coordinate_to_host(RECORD_LIST * lst)
+resource_rs_coordinate_to_host(RECORD_LIST * lst,RS_BUF * _b)
 {
 RESOURCE * ret;
 PN_RS_COORDINATE * cr;
@@ -1854,6 +1853,7 @@ int i;
 		ret->pr64.height[i] = r64->height[i];
 	}
 	ret->pr64.max_level = r64->max_level;
+ss_printf("LOAD LST-1\n");
 	gv_new_luster_option(ret,ret->pr64.max_level);
 	return ret;
 }
@@ -1890,13 +1890,13 @@ CHAIN_LIST * c;
 }
 
 RESOURCE * 
-resource_rs_draw_gb_to_host(RECORD_LIST * lst)
+resource_rs_draw_gb_to_host(RECORD_LIST * lst,RS_BUF *_b)
 {
 RESOURCE * ret;
 PN_RS_DRAW_GB * g;
 CHAIN_LIST * c;
 int i;
-extern void (*draw_gb_indicate_task)();
+extern void (*draw_gb_indicate_task)(TKEY);
 	g = lst->data;
 	ret = resource_rs_res_header(&c,&lst);
 	if ( ret == 0 )
@@ -2186,7 +2186,7 @@ _save_xl_sexp_to_cache(RECORD_LIST * tar,XL_SEXP * s)
 {
 STREAM * st;
 L_CHAR * ret;
-	st = s_open_string_write(&int_cm);
+	st = s_open_string_write(&extucs4_cm);
 	print_sexp(st,s,0);
 	ret = s_get_l_string(st);
 	_save_string_to_cache(tar,ret,1);
@@ -2559,7 +2559,7 @@ void gc_gb_sexp();
 	st = s_open_file(n_string(std_cm,filepath),O_RDONLY);
 	if ( st == 0 )
 		return -1;
-	s_set_cm(st,&int_cm);
+	s_set_cm(st,&extucs4_cm);
 	gc_push(0,0,"_get_rs_str");
 	*retp = ret = car(load = init_parse(st,filepath,filepath));
 	all_load(load);
@@ -2587,7 +2587,7 @@ STREAM * st;
 	st = s_open_file(n_string(std_cm,filepath),O_CREAT|O_TRUNC|O_RDWR,0644);
 	if ( st == 0 )
 		return -1;
-	s_set_cm(st,&int_cm);
+	s_set_cm(st,&extucs4_cm);
 	print_sexp(st,s,0);
 	s_close(st);
 	return 0;
