@@ -800,6 +800,7 @@ int minrect_flag;
 L_CHAR * f;
 XL_SEXP * _mod;
 XL_SEXP * ret;
+L_CHAR * cache_type;
 
 	setup_c_unit(
 		&r->h.cu,-1,f=ll_copy_str(get_url_str2(&r->h.entry)),
@@ -854,6 +855,17 @@ XL_SEXP * ret;
 			if ( get_type(ret) == XLT_ERROR )
 				return ret;
 		}
+		else if ( l_strcmp(tag->symbol.data,l_string(std_cm,"cache")) == 0 ) {
+			cache_type = get_sf_attribute(tag->symbol.field,l_string(std_cm,"type"));
+			if ( cache_type ) {
+				if ( l_strcmp(cache_type,l_string(std_cm,"clear")) == 0 )
+					r->h.flags |= RF_CACHE_CLEAR;
+				else if ( l_strcmp(cache_type,l_string(std_cm,"off")) == 0 )
+					r->h.flags |= RF_UNCACHE;
+				else if ( l_strcmp(cache_type,l_string(std_cm,"inherit")) == 0 )
+					r->h.flags |= RF_INHERIT;
+			}
+		}
 	}
 	if ( r->h.flags & RF_EDIT ) {
 		if ( r->h.edit_minrect.tl.x <= r->h.edit_minrect.br.x ) {
