@@ -297,6 +297,188 @@ get_resource_type_by_no(RESOURCE_TYPE_LIST * rt,int no)
 	return 0;
 }
 
+void
+insert_lw_service_code(LOAD_RESOURCE_SERVICE_CODE ** scp,XL_SEXP * s,int if_lock)
+{
+XL_SEXP * t,* sym;
+L_CHAR * name,* type;
+LOAD_RESOURCE_SERVICE_CODE * sc;
+AUTH_TABLE * tbl;
+
+ss_printf("INS ");
+print_sexp(s_stdout,s,0);
+ss_printf("\n");
+	if ( get_type(s) == XLT_ERROR ) {
+		if ( s->err.code != XLE_PROTO_PERMISSION_DENIED )
+			return;
+		s = s->err.data;
+	}
+	for ( ; get_type(s) == XLT_PAIR ; s = cdr(s) ) {
+		t = car(s);
+		if ( get_type(t) != XLT_PAIR )
+			continue;
+		sym = car(t);
+		if ( get_type(sym) != XLT_SYMBOL )
+			continue;
+		if ( l_strcmp(sym->symbol.data,l_string(std_cm,"service")) == 0 ) {
+			name = get_sf_attribute(sym->symbol.field,l_string(std_cm,"name"));
+			type = get_sf_attribute(sym->symbol.field,l_string(std_cm,"type"));
+			if ( name == 0 && type == 0 )
+				continue;
+ss_printf("NAME %ls\n",name);
+			if ( type == 0 )
+				tbl = 0;
+			else {
+				tbl = at_tbl_type_name(n_string(std_cm,type));
+				if ( tbl == 0 )
+					continue;
+			}
+			for ( sc = *scp ; sc ; sc = sc->next ) {
+				if ( !((name == 0 && sc->service == 0) ||
+					(name && l_strcmp(name,sc->service) == 0 )) )
+					continue;
+				if ( tbl && sc->type != tbl )
+					continue;
+				goto ok;
+			}
+			sc = d_alloc(sizeof(*sc));
+			sc->service = ll_copy_str(name);
+			sc->type = tbl;
+			
+			if ( if_lock )
+				lock_task(res_lock);
+			sc->next = *scp;
+			*scp = sc;
+			if ( if_lock )
+				unlock_task(res_lock,"insert");
+			
+		ok:	;
+		}
+		else if ( l_strcmp(sym->symbol.data,l_string(std_cm,"service-list")) == 0 ) {
+			insert_lw_service_code(scp,t,if_lock);
+		}
+	}
+}
+
+RESOURCE **
+insert_lw_service_code_flag_set_get_parent(RESOURCE * r,XL_SEXP * s)
+{
+RESOURCE ** lst;
+int nos,i;
+RES_PARENT_LIST * p;
+	lock_task(res_lock);
+	if ( r->h.p_list ) {
+		nos = 0;
+		for ( p = r->h.p_list ; p ; p = p->next , nos ++ ) {
+			insert_lw_service_code(&p->parent->h.auth_service_code,s,0);
+			if ( get_type(s) == XLT_ERROR && s->err.code == XLE_PROTO_PERMISSION_DENIED )
+				p->parent->h.flags |= RF_PERMISSION;
+		}
+		lst = d_alloc(sizeof(RESOURCE*)*(nos+1));
+		i = 0;
+		for ( p = r->h.p_list ; p ; p = p->next , i ++ )
+			lst[i] = p->parent;
+		lst[nos] = 0;
+	}
+	else {
+		insert_lw_service_code(&r->h.auth_service_code,s,0);
+		if ( get_type(s) == XLT_ERROR && s->err.code == XLE_PROTO_PERMISSION_DENIED )
+			r->h.flags |= RF_PERMISSION;
+		lst = d_alloc(sizeof(RESOURCE*)*2);
+		lst[0] = r;
+		lst[1] = 0;
+	}
+	unlock_task(res_lock,"copy_insert_lw_service_code");
+	return lst;
+}
+
+void
+free_lw_service_code(LOAD_RESOURCE_SERVICE_CODE * sc,int if_lock)
+{
+LOAD_RESOURCE_SERVICE_CODE * sc1;
+	if ( if_lock )
+		lock_task(res_lock);
+	for ( ; sc ; ) {
+		sc1 = sc;
+		sc = sc1->next;
+		d_f_ree(sc1->service);
+		d_f_ree(sc1);
+	}
+	if ( if_lock )
+		unlock_task(res_lock,"copy_insert_lw_service_code");
+}
+
+void
+copy_insert_lw_service_code(LOAD_RESOURCE_SERVICE_CODE ** dest,LOAD_RESOURCE_SERVICE_CODE * src,int if_lock)
+{
+LOAD_RESOURCE_SERVICE_CODE * d;
+	if ( if_lock )
+		lock_task(res_lock);
+	for (  ; src ; src = src->next ) {
+		for ( d = *dest ; d ; d = d->next ) {
+			if ( !((d->service == 0 && src->service == 0) ||
+				(d->service && src->service && l_strcmp(d->service,src->service) == 0 )) )
+				continue;
+			if ( d->type != src->type )
+				continue;
+			goto ok;
+		}
+		d = d_alloc(sizeof(*d));
+		d->service = ll_copy_str(src->service);
+		d->type = src->type;
+		d->next = *dest;
+		*dest = d;
+	ok:	;
+	}
+	if ( if_lock )
+		unlock_task(res_lock,"copy_insert_lw_service_code");
+}
+
+void
+copy_insert_lw_service_code_flag_set(RESOURCE * r,LOAD_RESOURCE_SERVICE_CODE * src)
+{
+	lock_task(res_lock);
+	copy_insert_lw_service_code(&r->h.auth_service_code,src,0);
+	r->h.flags |= RF_PERMISSION;
+	unlock_task(res_lock,"copy_insert_lw_service_code");
+}
+
+int
+copy_delete_lw_service_code(LOAD_RESOURCE_SERVICE_CODE ** dest,RESOURCE * r)
+{
+int flags;
+	lock_task(res_lock);
+	copy_insert_lw_service_code(dest,r->h.auth_service_code,0);
+	free_lw_service_code(r->h.auth_service_code,0);
+	r->h.auth_service_code = 0;
+	flags = r->h.flags & RF_PERMISSION;
+	r->h.flags &= ~RF_PERMISSION;
+	unlock_task(res_lock,"copy_insert_lw_service_code");
+	return flags;
+}
+
+
+void
+_insert_parent_list(RESOURCE * parent,RESOURCE * child)
+{
+RES_PARENT_LIST * pl;
+	for ( pl = child->h.p_list ; pl ; pl = pl->next )
+		if ( pl->parent == parent )
+			return;
+	pl = d_alloc(sizeof(*pl));
+	pl->parent = parent;
+	pl->next = child->h.p_list;
+	child->h.p_list = pl;
+}
+
+void
+insert_parent_list(RESOURCE * parent,RESOURCE * child)
+{
+	lock_task(res_lock);
+	_insert_parent_list(parent,child);
+	unlock_task(res_lock,"insert_parent_list");
+}
+
 void
 free_lrw_req_next(LOAD_RESOURCE_WORK * w)
 {
@@ -308,6 +490,7 @@ LOAD_RESOURCE_WORK * w2;
 		free_url(&w->url);
 		if ( w->target )
 			d_f_ree(w->target);
+		free_lw_service_code(w->auth_service_code,0);
 		d_f_ree(w);
 	}
 }
@@ -324,6 +507,7 @@ LOAD_RESOURCE_WORK * w2;
 		free_url(&w->url);
 		if ( w->target )
 			d_f_ree(w->target);
+		free_lw_service_code(w->auth_service_code,0);
 		d_f_ree(w);
 	}
 }
@@ -584,6 +768,7 @@ LOAD_RESOURCE_WORK * ret;
 	ret->meta_result = 0;
 	ret->data_result = 0;
 	ret->target = 0;
+	ret->auth_service_code = 0;
 	ret->rt = 0;
 	ret->_meta_ret = 0;
 
@@ -715,6 +900,7 @@ __load_meta_list_delete(int * ret_f,int ses,SYS_QUEUE * q,L_CHAR * key,
 {
 LOAD_RESOURCE_WORK * w,* wp, * wp2;
 XL_SEXP * ret,* s;
+int err_code;
 
 	*ret_f = 1;
 
@@ -757,10 +943,19 @@ XL_SEXP * ret,* s;
 		if ( w->que_next == 0 ) {
 log_print_sexp(LOG_WARNING,LOG_LAYER_GB,0,"resource loading error",ret,0);
 			w->int_remote_time += get_xltime() - w->remote_time;
+			if ( ret->err.code == XLE_PROTO_PERMISSION_DENIED ) {
+ss_printf("PERMISSION-ERR %ls\n",get_url_str2(&w->url));
+print_sexp(s_stdout,ret,0);
+ss_printf("\n");
+				insert_lw_service_code(&w->auth_service_code,ret,0);
+ss_printf(">>> %p\n",w->auth_service_code);
+				err_code = LRWE_ERROR_PERMISSION;
+			}
+			else	err_code = LRWE_ERROR_GET1;
 			if ( extend_flag )
-				res_end_op_extend(w,LRWE_ERROR_GET1,
+				res_end_op_extend(w,err_code,
 					w->result,0);
-			else	res_end_op(w,LRWE_ERROR_GET1,0);
+			else	res_end_op(w,err_code,0);
 		}
 		else {
 log_printf(LOG_WARNING,LOG_LAYER_GB,0,"+++++++++++++++++++++ ER\n");
@@ -1799,8 +1994,8 @@ RESOURCE * r;
 	}
 	else {
 		r = w->result;
-		free_lrw_req_next(w);
 	}
+	free_lrw_req_next(w);
 	return r;
 }
 
