@@ -80,8 +80,8 @@ int rrr_check(L_CHAR * st);
 void rrr_insert(L_CHAR * st);
 void rrr_delete(L_CHAR * st);
 
-void rr_task1();
-void rr_task2();
+void rr_task1(TKEY);
+void rr_task2(TKEY);
 
 void gc_routing();
 void gc_routing_get();
@@ -143,7 +143,7 @@ init_routing()
 	rr_que2.pri = PRI_FETCH_STRONG;
 	setup_queue(&rr_que2);
 
-	new_tick(err_route_tick,10,0);
+	new_tick((void(*)(int))err_route_tick,10,0);
 	
 	routing_global();
 }
@@ -651,7 +651,8 @@ int f;
 	for ( r = cc->root->next ; r != cc->root ; r = r->next ) {
 		if ( r->head == 0 )
 			continue;
-
+		if ( r->sts == RS_DELETE )
+			continue;
 		if ( l_strcmp(r->head->url,start) == 0 &&
 				l_strcmp(r->tail->url,target) == 0 ) {
 			delete_rring(r);
