@@ -119,9 +119,9 @@ make_dg()
 }
 
 void dm_scan_task();
-void dm_loading_task0();
-void dm_loading_task1();
-void dm_loading_task2();
+void dm_loading_task0(TKEY);
+void dm_loading_task1(TKEY);
+void dm_loading_task2(TKEY);
 
 void gc_dm_t();
 void gc_get_dm_t();
@@ -401,7 +401,7 @@ end:
 
 
 void
-dm_loading_task1()
+dm_loading_task1(TKEY _d)
 {
 XL_INTERPRETER * xli;
 
@@ -454,6 +454,7 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 				ret = _dgb_p2d_trailer(r,car(ld));
 				if ( get_type(ret) == XLT_ERROR ) {
 					set_inc_status_error(r,ret);
+					insert_lw_service_code_flag_set(r,ret);
 				}
 			}
 		}
@@ -482,6 +483,7 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 				ret = eval(e,car(ld));
 				if ( get_type(ret) == XLT_ERROR ) {
 					set_init_status_error(r,ret);
+					insert_lw_service_code_flag_set(r,ret);
 					log_print_sexp(LOG_ERROR,LOG_LAYER_GB,0,
 						"eval ERROR TILE",ret,0);
 					break;
@@ -509,7 +511,7 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 }
 
 void
-dm_loading_task2()
+dm_loading_task2(TKEY _d)
 {
 XL_INTERPRETER * xli;
 
@@ -948,7 +950,7 @@ rct->br.y - rct->tl.y);
 
 
 void
-dm_loading_task0()
+dm_loading_task0(TKEY _d)
 {
 XL_INTERPRETER * xli;
 
@@ -991,6 +993,7 @@ int type;
 		case XLT_ERROR:
 			log_printf(LOG_ERROR,LOG_LAYER_GB,0,"pdbp get error ");
 			set_inc_status_error(r,ret);
+			insert_lw_service_code_flag_set(r,ret);
 
 			er = -1;
 			goto end;
