@@ -45,6 +45,10 @@ gv_start_point_URL(XLISP_ENV * env,XL_SEXP * s,
 XL_SEXP *
 gv_gateway(XLISP_ENV * env,XL_SEXP * s,
 	XLISP_ENV * a,XL_SYM_FIELD * sf);
+XL_SEXP *
+gv_initial_warp_method(XLISP_ENV * env,XL_SEXP * s,
+	XLISP_ENV * a,XL_SYM_FIELD * sf);
+
 
 struct {
 	char		write_flag;
@@ -59,6 +63,7 @@ struct {
 	L_CHAR *	lang;
 	L_CHAR *	theme;
 	L_CHAR *	start_point_URL;
+	int		initial_warp_method;
 	L_CHAR *	gateway_server;
 	int		gateway_port;
 } view_param;
@@ -120,6 +125,26 @@ default_conditions(XLISP_ENV * env,XL_SEXP * s,
 }
 
 
+XL_SEXP *
+gv_initial_warp_method(XLISP_ENV * env,XL_SEXP * s,
+	XLISP_ENV * a,XL_SYM_FIELD * sf)
+{
+XL_SEXP * p;
+	p = get_el(s,1);
+	if ( get_type(p) != XLT_INTEGER ) {
+		return get_error(
+			s->h.file,
+			s->h.line,
+			XLE_SEMANTICS_TYPE_MISSMATCH,
+			l_string(std_cm,"initial-warp-method"),
+			List(	n_get_string("type missmatch"),
+				-1));
+	}
+	view_param.initial_warp_method = p->integer.data;
+	view_param.write_flag = 1;
+	return 0;
+}
+
 XL_SEXP *
 gv_start_point_URL(XLISP_ENV * env,XL_SEXP * s,
 	XLISP_ENV * a,XL_SYM_FIELD * sf)
@@ -153,7 +178,7 @@ XL_SEXP * p;
 			s->h.file,
 			s->h.line,
 			XLE_SEMANTICS_TYPE_MISSMATCH,
-			l_string(std_cm,"start-point-URL"),
+			l_string(std_cm,"gv-gateway"),
 			List(	n_get_string("type missmatch"),
 				-1));
 	}
@@ -173,7 +198,7 @@ XL_SEXP * p;
 			s->h.file,
 			s->h.line,
 			XLE_SEMANTICS_TYPE_MISSMATCH,
-			l_string(std_cm,"start-point-URL"),
+			l_string(std_cm,"gv-gateway"),
 			List(	n_get_string("type missmatch"),
 				-1));
 	}
@@ -605,6 +630,7 @@ STREAM * st;
 	s_printf(st,"<http-client>%s </http-client>\n",http_client);
 */
 
+	s_printf(st,"<initial-warp-method>%i</initial-warp-method>\n",view_param.initial_warp_method);
 	s_printf(st,"<default-conditions>\n");
 	print_sexp(st,view_param.default_conditions,PF_XML|PF_INDENT);
 	s_printf(st,"\n</default-conditions>\n");
@@ -698,6 +724,9 @@ XLISP_ENV * e,* top_e;
 	set_env(e,l_string(std_cm,"start-point-URL"),
 			get_func_prim(gv_start_point_URL,
 			FO_APPLICATIVE,0,2,2));
+	set_env(e,l_string(std_cm,"initial-warp-method"),
+			get_func_prim(gv_initial_warp_method,
+			FO_APPLICATIVE,0,2,2));
 	set_env(e,l_string(std_cm,"gateway"),
 			get_func_prim(gv_gateway,
 			FO_APPLICATIVE,0,3,3));
