@@ -188,6 +188,8 @@ int dd;
 
 int err_code;
 
+
+ss_printf("OPNE OLD MATRIX\n");
 	err_code = 1;
 
 	m = t->wait_matrix;
@@ -209,7 +211,6 @@ int err_code;
 		err = load_matrix_header(m,O_RDWR,0644);
 
 
-ss_printf("old_matrix err %i\n",err);
 		if ( err == 0 ) {
 			memset(&p,0,sizeof(p));
 			p.write_file = matrix_standard_write_file;
@@ -413,6 +414,8 @@ exist_file:
 	}
 
 	set_matrix_mode(m,MM_STANBY);
+	wf_insert_dirty_rect(ow->r,
+		&ow->r->h.minrect,WFF_LUSTER_DIRTY,120,10);
 	;
 	d_f_ree(t);
 	return;
@@ -710,7 +713,7 @@ int tim;
 			d = dirty_list;
 			dirty_list = d->next;
 			unlock_task(omx_lock,"_exec_dirty");
-ss_printf("EXEC DIRTY === INSERT DIRTY\n");
+//ss_printf("EXEC DIRTY === INSERT DIRTY\n");
 			wf_insert_dirty_rect(d->r,
 				&d->rct,WFF_LUSTER_DIRTY,120,10);
 			d_f_ree(d);
@@ -741,7 +744,7 @@ insert_dirty(RESOURCE * r,GB_RECT * rct)
 OMX_DIRTY * d;
 int t;
 
-ss_printf("OLD_MATRIX INSERT DIRTY\n");
+//ss_printf("OLD_MATRIX INSERT DIRTY\n");
 	lock_task(omx_lock);
 	d = d_alloc(sizeof(*d));
 	d->r = r;
@@ -917,6 +920,7 @@ ss_printf("** ** * RESET STREAM %i - %i\n",nr_count,wir);
 			ow1->trans_timeout --;
 			if (ow1->trans_timeout < INVALID_TRANS_TIMEOUT )
 				ow1->trans_timeout = INVALID_TRANS_TIMEOUT;
+			free_wfid_include_resource(wir);
 		}
 
 		switch ( get_type(otw1->data) ) {
@@ -927,6 +931,8 @@ ss_printf("EEEEEEE\n");
 
 			set_inc_status_error(r,otw1->data);
 
+			insert_lw_service_code_flag_set(r,otw1->data);
+
 			goto n1_free;
 		case XLT_NULL:
 		case XLT_PAIR:
@@ -966,13 +972,17 @@ check_point(n2);
 ss_printf("GET SESSION (%x)\n",n2);
 			if ( mn2->channel[CH_NET].data == 0 ) {
 			retry:
-				if ( get_type(data) == XLT_ERROR )
-{ss_printf("EEEEEEEEEEEE4\n");
+				if ( get_type(data) == XLT_ERROR ) {
+ss_printf("EEEEEEEEEEEE4\n");
+					insert_lw_service_code_flag_set(r,data);
+
 					break;
-}
+				}
 				err = list_error(car(data));
 				if ( get_type(err) == XLT_ERROR ) {
 ss_printf("EEEEEEEEEEE2\n");
+					insert_lw_service_code_flag_set(r,err);
+
 					data = cdr(data);
 					otw2->e_flag = 1;
 					continue;
