@@ -34,6 +34,7 @@
 #include	"xl.h"
 #include	"radar.h"
 #include	"h_layering.h"
+#include	"xlerror.h"
 
 #define CURRENT_SWITCH_TIMERAG	2
 #define ZONBIE_TIMEOUT	120
@@ -60,8 +61,8 @@ void check_flame_task();
 GBVIEW_FLAME * gbview_flame_list;
 SEM gbview_flame_lock;
 SEM irq_lock,in_lock,iom_lock;
-extern void (*draw_gb_indicate_task)();
-void indicate_info_task();
+extern void (*draw_gb_indicate_task)(TKEY);
+void indicate_info_task(TKEY);
 #define wf_indicate_lock(gf)	xx_wf_indicate_lock(gf,__FILE__,__LINE__)
 void change_task();
 void _indicate_flame_lock(int*);
@@ -86,7 +87,7 @@ init_win_flame()
 	iom_lock = new_lock(LL_ONMAP);
 	draw_gb_indicate_task = indicate_info_task;
 
-	create_task(change_task,0,PRI_DRAW_EXIT);
+	create_task((void(*)(TKEY))change_task,0,PRI_DRAW_EXIT);
 	
 	upper_layer_lock_tracer = _indicate_flame_lock;
 
@@ -395,6 +396,7 @@ F2OUTLIST * fo;
 
 //		exit_lock_resource(wf->draw,1);
 		*wfp = wf->next;
+		wf->next = 0;
 		wf->flags |= WFF_FREE_OUTLIST;
 		f = 1;
 		wakeup_task((int)gf);
@@ -997,7 +999,7 @@ RE_DATA * dp;
 	dp->usr = gf->radar_event_user_arg;
 	dp->event_func = gf->radar_event;
 	if ( dp->event_func )
-		new_tick((void(*)())__call_radar_event_func,0,(int)dp);
+		new_tick((void(*)(int))__call_radar_event_func,0,(int)dp);
 	else d_f_ree(dp);
 }
 
@@ -1030,7 +1032,7 @@ CB_ARG * a;
 	a->d_arg = gf->event_user_arg;
 	a->d_type = ET_CHANGE_BASE;
 	if ( a->d_event ) {
-		new_tick((void(*)())__call_flame_event,0,(int)a);
+		new_tick((void(*)(int))__call_flame_event,0,(int)a);
 	}
 	else {
 		d_f_ree(a);
@@ -1068,7 +1070,7 @@ CB_ARG * a;
 	a->d_arg = gf->event_user_arg;
 	a->d_type = ET_INSERT;
 	if ( a->d_event ) {
-		new_tick((void(*)())__call_flame_event,0,(int)a);
+		new_tick((void(*)(int))__call_flame_event,0,(int)a);
 	}
 	else {
 		d_f_ree(a);
@@ -1629,7 +1631,7 @@ _xx_free_win_flame(GBVIEW_FLAME * gf,WIN_FLAME * wf,char * __file,int __line)
 {
 
 	_backup_wf_flags(gf,wf);
-ss_printf("FREE %ls\n",	get_url_str2(&wf->draw->h.entry));
+ss_printf("FREE %s(%i) %ls\n",__file,__line,get_url_str2(&wf->draw->h.entry));
 	wf->flags |= WFF_FREE;
 	log_printf(LOG_MESSAGE,LOG_LAYER_GB,0,
 		"FREE(%s:%i) %ls\n",
@@ -1684,6 +1686,41 @@ WIN_FLAME * wf;
 }
 
 
+void
+_wf_auth_information(void * w)
+{
+void	(*d_event)(struct gbview_flame*,int,void*,void*);
+void *	d_arg;
+GV_AUTH_INFO * ai;
+GBVIEW_FLAME * gf;
+
+	ai = (GV_AUTH_INFO*)w;
+	gf = ai->gf;
+	wf_lock(gf);
+	d_event = gf->event;
+	d_arg = gf->event_user_arg;
+	wf_unlock(gf);
+	if ( d_event )
+		(*d_event)(gf,ET_AUTH,ai,d_arg);
+	d_f_ree(ai);
+}
+
+void
+wf_auth_information(RESOURCE * r)
+{
+WFID_INCLUDE_RESOURCE * wir,* wirp;
+GV_AUTH_INFO * ai;
+	wir = wf_search_wfid_include_resource(r);
+	for (wirp = wir ; wirp ; wirp = wirp->next ) {
+		ai = d_alloc(sizeof(*ai));
+		ai->id = wirp->id;
+		ai->r = r;
+		ai->gf = wirp->gf;
+		new_tick((void(*)(int))_wf_auth_information,0,(int)ai);
+	}
+	free_wfid_include_resource(wir);
+}
+
 void
 _wf_flame_redraw(GBVIEW_FLAME * gf)
 {
@@ -1735,6 +1772,121 @@ WIN_FLAME * wf;
 	return ret;
 }
 
+void
+adjust_point(GB_POINT *_pt)
+{
+GB_POINT pt;
+	pt = *_pt;
+	for ( ; pt.y > 3.0/2*M_PI ; pt.y -= 2*M_PI );
+	for ( ; pt.y < -M_PI/2 ; pt.y += 2*M_PI );
+	if ( pt.y > M_PI ) {
+		pt.y = - pt.y + M_PI;
+		pt.x += M_PI;
+	}
+	else if ( pt.y > M_PI/2 ) {
+		pt.y = M_PI - pt.y;
+		pt.x += M_PI;
+	}
+	*_pt = pt;
+}
+
+void
+get_rr_param2(REAL1 * reso,REAL1 * rotate,GB_POINT center1,GB_POINT center2,REAL1 d,RESOURCE * r)
+{
+double d_cita,d_phi;
+int er;
+double b;
+double _rotate;
+
+double aa;
+
+	center1.x = conv_unit(&er,r->h.cu.uenv,center1.x,r->h.cu.unit,l_string(std_cm,"rad"));
+	center1.y = conv_unit(&er,r->h.cu.uenv,center1.y,r->h.cu.unit,l_string(std_cm,"rad"));
+	center2.x = conv_unit(&er,r->h.cu.uenv,center2.x,r->h.cu.unit,l_string(std_cm,"rad"));
+	center2.y = conv_unit(&er,r->h.cu.uenv,center2.y,r->h.cu.unit,l_string(std_cm,"rad"));
+
+	adjust_point(&center1);
+	adjust_point(&center2);
+
+	d_cita = center2.x - center1.x;
+	d_phi = center2.y - center1.y;
+
+	aa = (cos(center1.y)*cos(center2.y)*cos(d_cita) + sin(center1.y)*sin(center2.y));
+	if ( aa > 1 )
+		b = 0;
+	else if ( aa < -1 )
+		b = M_PI;
+	else	b = acos(aa);
+	
+	if ( b == 0 )
+		_rotate = M_PI/2;
+	else {
+		_rotate = cos(center2.y)*sin(d_cita)/sin(b);
+		if ( _rotate > 1 )
+			_rotate = 0;
+		else if ( _rotate < -1 )
+			_rotate = M_PI;
+		else	_rotate = acos(_rotate);
+ss_printf("ROTATE %f - %f %f %f\n",_rotate,d_phi,d_cita,b);
+		if ( d_phi < 0 )
+			_rotate = - _rotate;
+	}
+
+	*rotate = _rotate;
+	*reso = conv_unit(&er,r->h.cu.uenv,d/b,l_string(std_cm,"dot/rad"),reso_c_unit(&r->h.cu));
+
+}
+
+
+void
+get_rr_param(REAL1 * reso,REAL1 * rotate,GB_POINT center1,GB_POINT center2,REAL1 d,RESOURCE * r)
+{
+double d_cita,d_phi,phi;
+double param1,param2;
+double a;
+double sin_alpha,cos_alpha;
+double pat1,pat2;
+int er;
+double rt;
+	center1.x = conv_unit(&er,r->h.cu.uenv,center1.x,r->h.cu.unit,l_string(std_cm,"rad"));
+	center1.y = conv_unit(&er,r->h.cu.uenv,center1.y,r->h.cu.unit,l_string(std_cm,"rad"));
+	center2.x = conv_unit(&er,r->h.cu.uenv,center2.x,r->h.cu.unit,l_string(std_cm,"rad"));
+	center2.y = conv_unit(&er,r->h.cu.uenv,center2.y,r->h.cu.unit,l_string(std_cm,"rad"));
+	phi = center1.y;
+	d_cita = center2.x - center1.x;
+	d_phi = center2.y - center1.y;
+	for ( ; d_cita > M_PI ; d_cita -= 2*M_PI );
+	for ( ; d_cita < -M_PI ; d_cita += 2*M_PI );
+	param1 = cos(phi) * d_cita;
+	param2 = d_phi;
+	
+	if ( param1 == 0 && param2 == 0 ) {
+		*reso = -1;
+	}
+	else if ( fabs(param1) < fabs(param2) ) {
+		a = param1/param2;
+		sin_alpha = 1/sqrt(1+a*a);
+		pat1 = fabs(d*sin_alpha/param2);
+		rt = atan(a);
+		if ( rt < 0 )
+			*rotate = - M_PI/2 - rt;
+		else	*rotate = M_PI/2 - rt;
+
+		*reso = conv_unit(&er,r->h.cu.uenv,pat1,l_string(std_cm,"dot/rad"),reso_c_unit(&r->h.cu));
+	}
+	else  {
+		a = param2/param1;
+		cos_alpha = 1/sqrt(1+a*a);
+		pat2 = fabs(d*cos_alpha/param1);
+		
+		*rotate = atan(a);
+
+		*reso = conv_unit(&er,r->h.cu.uenv,pat2,l_string(std_cm,"dot/rad"),reso_c_unit(&r->h.cu));
+	}
+
+}
+
+
 int
 _wf_set_current(GBVIEW_FLAME * gf,WIN_FLAME * now,WIN_FLAME * target)
 {
@@ -1748,7 +1900,7 @@ REAL1 d,dd;
 GB_POINT pp1,pp2;
 REAL1 s;
 unsigned int now_t;
-
+int r_f;
 	if ( gf->flame == 0 )
 		return 0;
 
@@ -1772,7 +1924,9 @@ unsigned int now_t;
 		if ( target == 0 && now_t - wf->out_base_time <
 					CURRENT_SWITCH_TIMERAG )
 			continue;
+			
 		d = gf->win_width/2;
+		r_f = 0;
 	retry:
 		_center[0].y = _center[1].y = _center[2].y
 				= gf->win_height/2;
@@ -1786,11 +1940,21 @@ unsigned int now_t;
 			continue;
 		if ( _reso[1] >= 0 ) {
 			i = 1;
+			if ( r_f == 0 && (wf->draw->c.geometory_type & GT_T_MASK) == GT_T_GLOBE_SUR ) {
+				d = d/4;
+				r_f = 1;
+				goto retry;
+			}
 			pp1.x = d;
 			pp1.y = 0;
 		}
 		else if ( _reso[2] >= 0 ) {
 			i = 2;
+			if ( r_f == 0 && (wf->draw->c.geometory_type & GT_T_MASK) == GT_T_GLOBE_SUR ) {
+				d = d/4;
+				r_f = 1;
+				goto retry;
+			}
 			pp1.x = -d;
 			pp1.y = 0;
 		}
@@ -1798,31 +1962,54 @@ unsigned int now_t;
 			d *= 0.5;
 			goto retry;
 		}
-		dd = distance(_center[i],_center[0]);
-		if ( dd == 0 ) {
-			d *= 1.2;
-			goto retry;
-		}
-		pp2 = p_sub(_center[i],_center[0]);
-		s = asin(pp2.y / dd);
-/*
-		if ( pp2.x > 0 )
-			rotate = s;
-		else	rotate = s - M_PI;
-*/
-		if ( pp2.x > 0 )
-			rotate = -s;
-		else if ( pp2.y > 0 )
-			rotate = - M_PI + s;
-		else	rotate = M_PI + s;
-		switch ( wf->draw->c.geometory_type & GT_A_MASK ) {
-		case GT_A_X_FOR|GT_A_Y_FOR:
-		case GT_A_X_REV|GT_A_Y_REV:
-			rotate = - rotate;
-		}
 		c = wf;
 		center = _center[0];
-		reso = d / dd;
+		if ( (wf->draw->c.geometory_type & GT_T_MASK) == GT_T_GLOBE_SUR ) {
+			get_rr_param2(&reso,&rotate,_center[0],_center[i],d,wf->draw);
+ss_printf("RESO %f %f\n",gf->flame_base_resolution,reso);
+			if ( reso < 0 ) {
+				reso = gf->flame_base_resolution;
+				dd = distance(_center[i],_center[0]);
+				if ( dd == 0 ) {
+					d *= 1.2;
+					goto retry;
+				}
+				pp2 = p_sub(_center[i],_center[0]);
+				s = asin(pp2.y / dd);
+				if ( pp2.x > 0 )
+					rotate = -s;
+				else if ( pp2.y > 0 )
+					rotate = - M_PI + s;
+				else	rotate = M_PI + s;
+			}
+			switch ( wf->draw->c.geometory_type & GT_A_MASK ) {
+			case GT_A_X_FOR|GT_A_Y_FOR:
+			case GT_A_X_REV|GT_A_Y_REV:
+				break;
+			default:
+				rotate = - rotate;
+			}
+		}
+		else {
+			dd = distance(_center[i],_center[0]);
+			if ( dd == 0 ) {
+				d *= 1.2;
+				goto retry;
+			}
+			pp2 = p_sub(_center[i],_center[0]);
+			s = asin(pp2.y / dd);
+			if ( pp2.x > 0 )
+				rotate = -s;
+			else if ( pp2.y > 0 )
+				rotate = - M_PI + s;
+			else	rotate = M_PI + s;
+			switch ( wf->draw->c.geometory_type & GT_A_MASK ) {
+			case GT_A_X_FOR|GT_A_Y_FOR:
+			case GT_A_X_REV|GT_A_Y_REV:
+				rotate = - rotate;
+			}
+			reso = d / dd;
+		}
 log_printf(LOG_MESSAGE,LOG_LAYER_GB,0,
 "*********SET  %f %f %f %f %f\n",reso,center.x,center.y,gf->flame_base_rotate,rotate);
 	}
@@ -3806,7 +3993,9 @@ int i;
 		set_surp(&ss,d_rect,1);
 		draw = wf_get_mh(p->gf,p->id,&mh);
 		if ( draw == 0 )
-			goto next2;
+			goto next3;
+		if ( draw == r )
+			goto draw_point;
 		map = get_map_between2(r,draw);
 		if ( map == 0 )
 			goto next2;
@@ -3816,6 +4005,7 @@ int i;
 				set_surp(&ss,&map->h.minrect,1);
 				break;
 			}
+	draw_point:
 		map_from_resource(mh,ss.ptr,ss.reso,SURP_NOS);
 		memset(ss.group,0,sizeof(ss.group));
 		_rct = get_surp_rect(&nos,&ss,0);
@@ -3829,11 +4019,14 @@ int i;
 		rct.tl.y -= ofs_h;
 		rct.br.x += ofs_w;
 		rct.br.y += ofs_h;
+
 		win_flame_dirty(p->gf,p->id,&rct,flags & mask,0);
 //	next1:
 		d_f_ree(_rct);
 	next2:
 		free_mh(mh);
+	next3:
+		;
 	}
 	free_wfid_include_resource(wir);
 }
@@ -4109,7 +4302,7 @@ GBVIEW_FLAME ** gfp,* gf;
 WIN_FLAME * wf;
 	lock_task(gbview_flame_lock);
 	if ( gf_zonbie_count == 0 ) {
-		del_tick(gf_zonbie_tick);
+		del_tick((void(*)(int))gf_zonbie_tick);
 		goto end;
 	}
 	for ( gfp = &gbview_flame_list ; *gfp ; ) {
@@ -4410,7 +4603,7 @@ WIN_FLAME * wf;
 	if ( wf ) {
 		if ( r ) {
 			wf->dr_time = get_xltime() + wf->dr_interval;
-			new_tick((void(*)())dr_tick,-wf->dr_interval-1,(int)gf);
+			new_tick((void(*)(int))dr_tick,-wf->dr_interval-1,(int)gf);
 			wf->dr_interval *= 2;
 		}
 		else {
@@ -4500,14 +4693,14 @@ ok:
 		}
 		_call_flame_change_base_event(gf);
 	}
-	if ( wf->flags & WFF_BASE_LOCK ) {
+	if ( wf->flags & (WFF_BASE_LOCK) ) {
 		for ( wf2 = gf->flame ; wf2 ; wf2 = wf2->next ) {
 			if ( wf2 == wf )
 				continue;
-			wf2->flags &= ~WFF_BASE_LOCK;
+			wf2->flags &= ~(WFF_BASE_LOCK);
 		}
 		for ( ri = gf->resource_list ; ri ; ri = ri->next )
-			ri->flags &= ~WFF_BASE_LOCK;
+			ri->flags &= ~(WFF_BASE_LOCK);
 	}
 	if ( (wf->flags & WFF_BASE_LOCK) != (f & WFF_BASE_LOCK) ) {
 		_call_re_base_lock(gf,ET_LOCK_BASE);
@@ -4534,3 +4727,17 @@ WIN_FLAME * wf;
 }
 
 
+void
+insert_lw_service_code_flag_set(RESOURCE * r,XL_SEXP * s)
+{
+RESOURCE ** lst;
+int i;
+	lst = insert_lw_service_code_flag_set_get_parent(r,s);
+	
+	if ( get_type(s) == XLT_ERROR && s->err.code == XLE_PROTO_PERMISSION_DENIED )
+		for ( i = 0 ; lst[i] ; i ++ ) 
+			wf_auth_information(lst[i]);
+	d_f_ree(lst);
+}
+
+
