@@ -383,7 +383,7 @@ typedef struct crd_list {
 #define CLS_KEEP		1
 #define CLS_REMOVE		2
 #define CLS_INSERT		3
-	unsigned 		base_lock:1;
+	unsigned 		base_lock:2;
 } CRD_LIST;
 
 typedef struct beam_query {
@@ -751,6 +751,8 @@ XL_SEXP *
 wp2sexp(WARP_POINT * wp);
 WARP_POINT *
 rc_copy_warp_point(WARP_POINT * wp);
+int 
+rc_trackback(XL_SEXP ** retp,RADAR_CACHE * rc_ptr,L_CHAR * path);
 
 
 #endif
