@@ -158,6 +158,7 @@ void xx_set_buffer(void *,char *,int);
 #define set_buffer(x)	xx_set_buffer(x,__FILE__,__LINE__)
 char * get_preference_path();
 char * get_peripheral_path();
+char * get_tmp_dir();
 int get_field(XL_SEXP * s,...);
 int launch_proc(
 	char * str,
@@ -170,7 +171,7 @@ void divide_string(DIV_STR * str,L_CHAR * div);
 void init_tick();
 void new_tick(void (*func)(int),int interval,int data);
 void del_tick(void (*func)(int));
-void del_tick_with_data(void (*func)(),int);
+void del_tick_with_data(void (*func)(int),int);
 void new_timeout(int,int);
 void del_timeout(int);
 void timeout_exit(int,int,int (*)());
@@ -342,6 +343,9 @@ delete_codehash(CODEHASH * ch,int rev,int forwd,int flags);
 void tick_start_lock();
 void tick_start_unlock();
 
+char *
+get_abstract_locale(char * str);
+
 #ifdef __cplusplus
 }
 #endif
