@@ -33,6 +33,7 @@ extern "C" {
 #include	"regular.h"
 #include	"queue.h"
 #include	"version.h"
+#include	"authentification.h"
 
 #define INTERPRETER_HASH_SIZE	20
 #define THREAD_HASH_SIZE 	20
@@ -300,6 +301,8 @@ typedef struct xl_interpreter {
 
 	int		delay_que_cnt;
 
+	struct auth_connection_set *	auth_c_set;
+
 	char *		__file;
 	int		__line;
 } XL_INTERPRETER;
@@ -476,7 +479,7 @@ void connect_unlock(XL_SEXP * s,int id,L_CHAR * dir);
 
 XL_SEXP *
 load_file(XLISP_ENV * env,XL_SEXP * s,int type,L_CHAR * filename,
-	L_CHAR * ,AUTOMATON * ,int,void (*func)(),void * work);
+	L_CHAR * ,AUTOMATON * ,int,void (*func)(int,void*),void * work);
 void send_code_sync(int iid);
 int
 lock_file(
@@ -522,7 +525,7 @@ XL_SEXP * err_handler(XL_SEXP *,XL_FILE *,int);
 #define RO_SORT1	0x00000001
 #define RO_SORT2	0x00000002
 
-int xl_log_vprintf(int,int,LOG_NODE_DATA *,char*,va_list);
+int xl_log_vprintf(int,int,void *,char*,va_list);
 void set_log_path(L_CHAR*,int,int);
 int
 log_print_sexp(
@@ -980,6 +983,8 @@ void *
 xl_get_ri(int * err,int * w,int * h,ri_que_cf func,void * cf_data,L_CHAR * path);
 void init_xl_ri();
 extern XL_SEXP * (*convert_code_ptr)(XL_SEXP * st,LCZ_SET * set,int flags);
+void
+set_arg(int _argc,char ** _argv,int v_offset);
 
 
 #ifdef __cplusplus
