@@ -170,7 +170,8 @@ int gblisp_relay_error(XL_FILE * to,int line,XL_FILE * from);
 
 CODE_METHOD * get_cm(XL_SEXP *);
 
-void set_close_func(XL_FILE * f,void (*func)(),void * work);
+void
+set_close_func(XL_FILE * f,void (*func)(int,void*),void * work);
 
 void setcr_lock();
 void setcr_unlock();
