@@ -1,6 +1,4 @@
 /***********************************************************************
-顼桼ƥƥ
-ʳ˥
 ************************************************************************/
 #ifndef	_GIF_RGB_H_
 #define	_GIF_RGB_H_
