@@ -38,7 +38,7 @@ void
 init_wct()
 {
 	wct_lock = new_lock(LL_WCT);
-	new_tick(tick_lc_table,10,0);
+	new_tick((void(*)(int))tick_lc_table,10,0);
 }
 
 
@@ -580,7 +580,7 @@ LC_CWS cws;
 	for ( p =  0 ; cnt ; str ++ , cnt -- ) {
 		ls = _wct_convert(&cws,*str,size);
 		if  ( ls.ch == LCC_ERROR ) {
-ss_printf("CONVERT ERROR\n");
+ss_printf("CONVERT ERROR %x\n",*str);
 			sprintf(buf,"&cx%x;",
 				(int)*str);
 			_len = strlen(buf);
@@ -652,7 +652,7 @@ FONT_PRI * fpp;
 	for ( ; fpn->font ; fpn ++ ) {
 		if ( check_font_name_and_cond(cond,fpn->font) < 0 )
 			continue;
-		fpp->font = _lc_new_font(fpn->font,fpn->lcz,fpn->mask);
+		fpp->font = _lc_new_font(fpn->font,fpn->lcz,fpn->mask,fpn->lcz_cov,fpn->mask_cov);
 
 		if ( fpp->font == 0 )
 			continue;
