@@ -98,7 +98,7 @@ init_d_alloc()
 #ifndef DONT_USE_LOCK
 	if ( md_flag == 1 )
 		er_panic("init_d_alloc");
-	new_tick(list_tick,30,0);
+	new_tick((void(*)(int))list_tick,30,0);
 	create_task(memory_debug_task,PRI_FETCH,0);
 #endif
 }
