@@ -34,6 +34,7 @@
 #define SCRIPT_ERR
 */
 
+
 #define TIME_DOMAIN	120
 
 typedef struct load_work {
@@ -59,7 +60,7 @@ int load_indicate_tick_end_flag;
 void _close_matrix(MATRIX * m);
 
 MATRIX *
-_open_matrix(L_CHAR * neturl,L_CHAR * filename,L_CHAR * key,void (*open_method)(),void * work);
+_open_matrix(L_CHAR * neturl,L_CHAR * filename,L_CHAR * key,void (*open_method)(MATRIX_TOKEN*),void * work);
 
 MATRIX_NODE * _get_matrix_node(int * errp,MATRIX * m,INTEGER64 * dim_code,int,INTEGER64,XL_SEXP **);
 
@@ -171,7 +172,7 @@ init_matrix()
 	matrix_que.flags = QF_PRI_FIFO;
 	matrix_que.gc_func = 0;
 	matrix_que.gc_get = 0;
-	matrix_que.key_func = matrix_que_task;
+	matrix_que.key_func = (void(*)(TKEY))matrix_que_task;
 	matrix_que.pri = PRI_DRAW;
 	setup_queue(&matrix_que);
 
@@ -234,7 +235,7 @@ init_matrix()
 	init_sbPrimitive(matrix_xl_env);
 	init_sbHeuristicLayering(matrix_xl_env);
 	
-	new_tick(matrix_access_tick,STAT_TICK,0);
+	new_tick((void(*)(int))matrix_access_tick,STAT_TICK,0);
 }
 
 char * 
@@ -399,6 +400,22 @@ _delete_matrix_ring(MATRIX * m)
 	m->mx_prev->mx_next = m->mx_next;
 }
 
+
+
+MATRIX*
+_search_matrix_filename(L_CHAR * filename)
+{
+MATRIX * ret;
+	for ( ret = matrices_root->mx_next ;
+			ret != matrices_root ; ret = ret->mx_next ) {
+		if ( ret->filename == 0 )
+			continue;
+		if ( l_strcmp(ret->filename,filename) == 0 )
+			return ret;
+	}
+	return 0;
+}
+
 void
 matrix_que_task()
 {
@@ -628,10 +645,17 @@ MATRIX_TOKEN * t;
 }
 
 MATRIX *
-_open_matrix(L_CHAR * neturl,L_CHAR * filename,L_CHAR * key,void (*open_method)(),void * work)
+_open_matrix(L_CHAR * neturl,L_CHAR * filename,L_CHAR * key,void (*open_method)(MATRIX_TOKEN*),void * work)
 {
 MATRIX * ret;
 MATRIX_SEXP * d;
+
+
+	if ( filename ) {
+		ret = _search_matrix_filename(filename);
+		if ( ret )
+			return 0;
+	}
 	ret = d_alloc(sizeof(*ret));
 	memset(ret,0,sizeof(*ret));
 	ret->neturl = ll_copy_str(neturl);
@@ -1677,7 +1701,6 @@ see_access_list(t->access_list);
 
 		ret = eval(e,car(t->cal_target));
 
-
 		if ( get_type(ret) != XLT_ERROR ) {
 
 #ifdef SCRIPT_DEBUG
@@ -1851,6 +1874,9 @@ void
 _matrix_token_error(MATRIX_TOKEN * t)
 {
 	if ( t->err_jump_status >= 0 ) {
+#ifdef SCRIPT_ERR
+ss_printf("MATRIX_TOKEN_ERR %p NODE=%p %i (ERR_JUMP_STATUS)\n",t,t->process_node,t->err_jump_status);
+#endif
 		t->process_node->status = t->err_jump_status;
 		wakeup_task((int)t->process_node);
 		_matrix_send_result(t);
@@ -2286,6 +2312,7 @@ unsigned int key;
 			_get_matrix_access(n);
 			if ( errp )
 				*errp = ME_NO_NODE;
+			break;
 		case MS_PROCESS_ERR_1:
 			if ( access < 0 || access == GN_ERROR_NORETRY ) {
 				if ( errp )
@@ -2295,6 +2322,7 @@ unsigned int key;
 			}
 			n->status = MS_PROCESS;
 			wakeup_task((int)n);
+ss_printf("VISU trigger %p\n",n);
 			_matrix_trigger_access(n,MI_VISU_1_TP,0);
 			if ( errp )
 				*errp = ME_NO_NODE;
@@ -2393,6 +2421,8 @@ ss_printf("GMNW %p\n",n);
 	}
 	if ( errp && err )
 		*errp = err;
+	if ( err == 0 )
+		_lock_node(n,0);
 	unlock_task(matrix_lock,"get_matrix_node");
 	return n;
 }
@@ -2504,6 +2534,24 @@ allset_dim_code_index(MATRIX_NODE * n,int dirty)
 	unlock_task(matrix_lock,"insert_dim_code_index");
 }
 
+void
+_vecset_dim_code_index(MATRIX_NODE * n,char * lst,int dirty)
+{
+int i;
+	if ( n->nlist_dim_bit_field == 0 )
+		return;
+	for ( i = 0 ; i < n->matrix->dim_bit_field ; i ++ )
+		n->nlist_dim_bit_field[i] |= lst[i];
+}
+
+void
+vecset_dim_code_index(MATRIX_NODE * n,char * lst,int dirty)
+{
+	lock_task(matrix_lock);
+	_vecset_dim_code_index(n,lst,dirty);
+	unlock_task(matrix_lock,"insert_dim_code_index");
+}
+
 
 void
 _insert_dim_code_index(MATRIX_NODE * n,INTEGER64 * dim_code,int dirty)
@@ -2514,12 +2562,15 @@ int pt_st,pt_end;
 int mid;
 int lev;
 int i;
+int _dirty;
 	if ( _check_dim_code(n,dim_code) )
 		return;
 	if ( n->nlist_dim_bit_field ) {
 		ix = _get_dim_code_index(n,dim_code);
+		if ( !(n->nlist_dim_bit_field[ix/8] & (1<<(ix % 8)) ) )
+			_dirty = 1;
 		n->nlist_dim_bit_field[ix/8] |= (1<<(ix % 8));
-		if ( dirty )
+		if ( dirty && _dirty )
 			_set_dirty_file(n);
 		return;
 	}
@@ -2537,7 +2588,7 @@ int i;
 			pt_end = mid;
 			break;
 		case 0:
-			er_panic("_insert_dim_code_index");
+			return;
 		case 1:
 			pt_st = mid+1;
 			break;
@@ -2547,7 +2598,6 @@ int i;
 		n->nlist_dim_addr[i] = n->nlist_dim_addr[i-1];
 	n->nlist_dim_addr[pt_st] = _copy_dim_code(n->matrix,dim_code);
 	dim_code[0] = lev;
-
 	if ( dirty )
 		_set_dirty_file(n);
 }
@@ -2582,8 +2632,16 @@ INTEGER64 lev;
 	for ( ; dim_code[0] >= lev ; dim_code[0] -- , prev = _ret ) {
 		err = 0;
 		_ret = _get_matrix_node(&err,m,dim_code,access,lev,0);
-		if ( err == 0 )
+		if ( err == 0 ) {
 			ret = _ret;
+			switch ( access ) {
+			case GN_LIST_CREATE:
+				if ( prev == 0 )
+					continue;
+				_insert_dim_code_index(prev,dim_code,1);
+				continue;
+			}
+		}
 		else {
 			if ( err == ME_MATRIX_ERR )
 				break;
@@ -3282,12 +3340,12 @@ MX_DIM_CODE_LIST * lst, * lst2, * ret;
 	else {
 		pp = n->nlist_dim_addr;
 		pp_len = n->nlist_dim_addr_len;
-		if ( pp ) {
+		if ( pp == 0 ) {
 			ret = 0;
 			goto end;
 		}
 		lst = 0;
-		for ( ; pp_len  ; pp ++ , pp_len ) {
+		for ( ; pp_len  ; pp ++ , pp_len -- ) {
 			lst2 = d_alloc(sizeof(*lst2));
 			lst2->dc = copy_dim_code(m,*pp);
 			lst2->next = lst;
@@ -3357,7 +3415,7 @@ load_indicate(int start)
 	if ( start ) {
 		for ( ; load_indicate_tick_end_flag ; )
 			sleep_sec(1);
-		new_tick(load_indicate_tick,2,0);
+		new_tick((void(*)(int))load_indicate_tick,2,0);
 	}
 	else {
 		load_indicate_tick_end_flag = 1;
@@ -3667,7 +3725,6 @@ INTEGER64 *_end,*_start;
 		}
 		ret += sq;
 	}
-ss_printf("GLA %lli\n",ret);
 	return ret;
 }
 
@@ -3691,9 +3748,9 @@ MATRIX_NODE * n;
 		n = get_matrix_node_wait(&err,w->m,dim_code,mst->gn_create);
 		if ( err < 0 )
 			return err;
-		unlock_node(n,0);
 		mst->channel_data = get_matrix_node_channel(&err,&n,w->m,dim_code,mst->channel,
 					mst->gn_tree_node,mst->gn_create,0);
+		unlock_node(n,0);
 		mst->n = n;
 		if ( err < 0 )
 			return err;
@@ -3882,6 +3939,7 @@ int err;
 
 //	mx_file_sync_create_node(m);
 	
+	ret = 0;
 	set_matrix_env(m,"create-node","enable");
 
 	w.m = m;
@@ -3923,6 +3981,7 @@ int er_data;
 		return -1;
 	lock_task(matrix_lock);
 	_lock_node(n,0);
+	_matrix_node_channel_lock(n);
 	m = n->matrix;
 	size = s->raw.size;
 	start = ptr =(unsigned char*) s->raw.data;
@@ -3970,6 +4029,7 @@ int er_data;
 		}
 		ptr += data_size;
 	}
+	_matrix_node_channel_unlock(n,0);
 	_unlock_node(n,0);
 	unlock_task(matrix_lock,"");
 	return 0;
@@ -3991,7 +4051,6 @@ int size;
 XL_SEXP * ret;
 CHAIN_LIST64 * rl_ptr;
 
-
 	rl = new_recordlist64(0,0);
 	m = n->matrix;
 	if (  m->dim_bit_field ) {
@@ -4043,5 +4102,182 @@ set_dirty_file_sb(MX_STRUCT_BLOCK * b)
 	unlock_task(matrix_lock,"set_dirty_file_sb");
 }
 
+int acc_size;
+
+int
+matrix_copy_node(MATRIX * dest,MATRIX * src,INTEGER64 * dc,int * ch_list,int copy_flags)
+{
+MATRIX_NODE * d1, * s1;
+int err;
+int ch;
+int i;
+
+//MATRIX_ALLOC_BLOCK_PARAM * wk;
+
+ss_printf("NODE %s\n",pt_dc(src,dc,PTDC_PIXEL_1));
+	err = 0;
+	s1 = get_matrix_node_wait(&err,src,dc,GN_ERROR_NORETRY);
+	if ( err < 0 ) {
+		if ( err == ME_NO_NODE )
+			return 0;
+		return err;
+	}
+	if ( s1->status != MS_OK )
+		er_panic("matrix_copy_node");
+	err = 0;
+	d1 = get_matrix_node_wait(&err,dest,dc,GN_NODE_CREATE);
+	if ( err < 0 ) {
+		unlock_node(s1,0);
+		return err;
+	}
+	if ( d1->status != MS_OK )
+		er_panic("matrix_copy_node(2)");
+
+	matrix_node_channel_lock(s1);
+	matrix_node_channel_lock(d1);
+	for ( i = 1 ; i <= src->p.dim ; i ++ )
+		if ( dc[i] < 0 )
+			goto parameter;
+	for ( ; *ch_list >= 0 ; ch_list ++ ) {
+		ch = *ch_list;
+		if ( src->p.channel_nos <= ch )
+			continue;
+		if ( src->channel_info[ch].data_type == 0 )
+			continue;
+		if ( s1->channel[ch].data == 0 )
+			continue;
+		if ( d1->channel[ch].data ) {
+			(*dest->channel_info[ch].data_type->free_data)
+				(dest->channel_info[ch].data_type,d1->channel[ch].data);
+		}
+		d1->channel[ch].data = (src->channel_info[ch].data_type->alloc_copy)
+				(src->channel_info[ch].data_type,s1->channel[ch].data,MD_DALLOC,0,
+				__FILE__,__LINE__);
+/*
+wk = d1->channel[ch].data;
+acc_size += wk->size;
+ss_printf("CH %i %p - %i\n",ch,d1->channel[ch].data,acc_size);
+*/
+	}
+	for ( ch = 0 ; ch < src->p.channel_nos ; ch ++ ) {
+		if ( src->channel_info[ch].data_type == 0 )
+			continue;
+		if ( (src->channel_info[ch].flags & copy_flags) == 0 )
+			continue;
+		if ( s1->channel[ch].data == 0 )
+			continue;
+		if ( d1->channel[ch].data ) {
+			(*dest->channel_info[ch].data_type->free_data)
+				(dest->channel_info[ch].data_type,d1->channel[ch].data);
+		}
+		d1->channel[ch].data = (src->channel_info[ch].data_type->alloc_copy)
+				(src->channel_info[ch].data_type,s1->channel[ch].data,MD_DALLOC,0,
+				__FILE__,__LINE__);
+	}
+	goto next;
+parameter:
+	for ( ch = 0 ; ch < src->p.channel_nos ; ch ++ ) {
+		if ( src->channel_info[ch].data_type == 0 )
+			continue;
+		if ( s1->channel[ch].data == 0 )
+			continue;
+		if ( d1->channel[ch].data ) {
+			(*dest->channel_info[ch].data_type->free_data)
+				(dest->channel_info[ch].data_type,d1->channel[ch].data);
+		}
+		d1->channel[ch].data = (src->channel_info[ch].data_type->alloc_copy)
+				(src->channel_info[ch].data_type,s1->channel[ch].data,MD_DALLOC,0,
+				__FILE__,__LINE__);
+				
+	}
+next:
+	if ( dest->dim_bit_field ) {
+		vecset_dim_code_index(d1,s1->nlist_dim_bit_field,1);
+	}
+	else {
+		for ( i = 0; i < s1->nlist_dim_addr_len ; i ++ ) {
+			insert_dim_code_index(d1,s1->nlist_dim_addr[i],1);
+		}
+	}
+	matrix_node_channel_unlock(s1,0);
+	matrix_node_channel_unlock(d1,NF_DIRTY);
+
+	unlock_node(s1,0);
+	unlock_node(d1,0);
+	return 0;
+}
+
+int
+matrix_copy(MATRIX * dest,MATRIX * src,int * ch_list,int copy_flags)
+{
+INTEGER64 * target,* last;
+MX_DIM_CODE_LIST * dc_list,* dcl;
+int ret;
+int f;
+int i;
+
+	if ( src->p.dim != dest->p.dim )
+		return ME_INVALID_PARAM;
+	target = d_alloc(sizeof(INTEGER64)*(src->p.dim+1));
+	last = d_alloc(sizeof(INTEGER64)*(src->p.dim+1));
+	ret = mx_scale_of_dim_code(target,last,src);
+	if ( ret < 0 )
+		goto end;
+	f = 0;
+	dc_list = 0;
+	for ( ; ; ) {
+		for ( i = 0 ; i <= src->p.dim ; i ++ ) {
+			if ( target[i] > last[i] )
+				goto end2;
+			if ( target[i] < last[i] )
+				break;
+		}
+		dc_list = mx_search_level_node(src,target,100);
+		if ( dc_list == 0 )
+			break;
+		if ( f ) {
+			for ( i = 0 ; i <= src->p.dim ; i++ ) {
+				if ( target[i] != dc_list->dc[i] )
+					break;
+			}
+			if ( i > src->p.dim ) {
+				dcl = dc_list;
+				dc_list = dc_list->next;
+				d_f_ree(dcl->dc);
+				d_f_ree(dcl);
+			}
+			if ( dc_list == 0 ) {
+				target[0] ++;
+				for ( i = 1 ; i <= src->p.dim ; i ++ )
+					target[i] = 0;
+				f = 0;
+				continue;
+			}
+		}
+		f = 0;
+		for ( ; dc_list ; ) {
+			dcl = dc_list;
+			dc_list = dc_list->next;
+			ret = matrix_copy_node(dest,src,dcl->dc,ch_list,copy_flags);
+			memcpy(target,dcl->dc,sizeof(INTEGER64)*(src->p.dim+1));
+			f = 1;
+			d_f_ree(dcl->dc);
+			d_f_ree(dcl);
+			if ( ret < 0 )
+				goto end2;
+		}
+	}
+end2:
+	for ( ; dc_list ; ) {
+		dcl = dc_list;
+		dc_list = dcl->next;
+		d_f_ree(dcl->dc);
+		d_f_ree(dcl);
+	}
+end:
+	d_f_ree(target);
+	d_f_ree(last);
+	return ret;
+}
 
 
