@@ -101,7 +101,7 @@ void
 init_mx_file()
 {
 	mx_file_lock = new_lock(LL_MX_FILE);
-	new_tick(mx_file_gc_tick,MLOCK_LIFE_TIME/2,0);
+	new_tick((void(*)(int))mx_file_gc_tick,MLOCK_LIFE_TIME/2,0);
 }
 
 void
@@ -211,7 +211,7 @@ check_pdb64(w->pdb_fd);
 	if ( w->subheader_fofs )
 		load_subheader(m,1);
 	if ( w->subheader.flags & MXF_WRITE ) {
-		close_filespace64(w->pdb_fd);
+		l_close_filespace64(w->pdb_fd);
 		w->pdb_fd = 0;
 		mx_open_files_cnt --;
 		call_unlock(w->lock_d);
@@ -293,7 +293,7 @@ MX_FILE_WORK * w;
 
 	if ( w->subheader_fofs )
 		save_subheader(m,0);
-	close_filespace64(w->pdb_fd);
+	l_close_filespace64(w->pdb_fd);
 	w->pdb_fd = 0;
 	mx_open_files_cnt --;
 	call_unlock(w->lock_d);
@@ -541,7 +541,7 @@ MX_FILE_WORK * w;
 
 	w->subheader = *sh;
 /*
-	w->node_root = get_root64(&w->favt64_err,
+	w->node_root = l_get_root64(&w->favt64_err,
 		w->pdb_fd,
 		w->subheader.node_root,
 		mx_dim_code_endian);
@@ -652,7 +652,7 @@ ss_printf("H-1 " I64_FORMAT "\n",h->h.size);
 	w->subheader.cache_next =
 		w->subheader.cache_prev = 
 		w->subheader_fofs;
-	rt = favt64_alloc_root(w->pdb_fd,FAT_MX_NODE,mx_dim_code_endian);
+	rt = l_favt64_alloc_root(w->pdb_fd,FAT_MX_NODE,mx_dim_code_endian);
 	w->subheader.node_root = rt->h.fofs;
 
 	save_subheader(m,0);
@@ -738,7 +738,7 @@ ss_printf("load_matrix_header-1 %i\n",err);
 	h = get_file_record64((U_INTEGER64*)&w->header_fofs,
 		w->pdb_fd,PNT_MX_HEADER,0);
 	if ( h == 0 ) {
-		close_filespace64(w->pdb_fd);
+		l_close_filespace64(w->pdb_fd);
 		mx_open_files_cnt --;
 		w->pdb_fd = 0;
 		call_unlock(w->lock_d);
@@ -1049,11 +1049,13 @@ unsigned char * ptr;
 	n = read_filespace64f(w->pdb_fd,fofs);
 	if ( n == 0 ) {
 		finish_file_access(m,0);
+ss_printf("load_raw_matrix_node1\n");
 		return -1;
 	}
 	change_endian_header64(&n->h);
 	if ( n->h.type != PNT_MX_NODE ) {
 		finish_file_access(m,0);
+ss_printf("load_raw_matrix_node2 = %i\n",n->h.type);
 		return -2;
 	}
 	*ret = *n;
@@ -1233,14 +1235,14 @@ FAVT64_ROOT * rt;
 	}
 	if ( mx_n.d.p3.f.nlist_dim_addr )
 		free_filespace64(w->pdb_fd,mx_n.d.p3.f.nlist_dim_addr);
-	rt = get_root64(&w->favt64_err,
+	rt = l_get_root64(&w->favt64_err,
 		w->pdb_fd,
 		w->subheader.node_root,
 		mx_dim_code_endian);
-	n = favt64_delete(&er,rt,&rt->node,dim_code,mx_dim_code_cmp,m);
+	n = l_favt64_delete(&er,rt,&rt->node,dim_code,mx_dim_code_cmp,m);
 	if ( n == 0 )
 		er_panic("mx_cache_purge");
-	favt64_free_node(n);
+	l_favt64_free_node(n);
 }
 
 
@@ -1404,11 +1406,12 @@ void * d;
 FAVT64_ROOT * rt;
 INTEGER64 * dim_code;
 int i;
+int ret_err = -1;
 
 	m = n->matrix;
 
 	if ( start_file_access(m) < 0 )
-		return -1;
+		return ME_CANNOT_LOCK;
 
 	w = m->file_work;
 
@@ -1417,18 +1420,20 @@ int i;
 	ptr = (unsigned char*)(dc+1);
 	ptr = get_compressed_dim_code(ptr,n->dim_code,m->p.dim);
 
-	rt = get_root64(&w->favt64_err,
+	rt = l_get_root64(&w->favt64_err,
 		w->pdb_fd,
 		w->subheader.node_root,
 		mx_dim_code_endian);
-	fn = favt64_search(&w->favt64_err,
+	fn = l_favt64_search(&w->favt64_err,
 			rt,
-			root_node64(&w->favt64_err,rt),
+			l_root_node64(&w->favt64_err,rt),
 			dc,mx_dim_code_cmp,m);
 	d_f_ree(dc);
 
-	if ( fn == 0 )
+	if ( fn == 0 ) {
+		ret_err = w->favt64_err;
 		goto err;
+	}
 	dc = fn->data;
 	n->fofs = dc->fofs;
 	wakeup_task((int)n);
@@ -1436,8 +1441,12 @@ int i;
 	dim_code = d_alloc(sizeof(INTEGER64)*(m->p.dim+1));
 
 	if ( m->dim_bit_field ) {
+	char * field;
+		field = d_alloc(m->dim_bit_field);
 		load_raw_matrix_node(
-			&mx_n,&org,dim_code,n->nlist_dim_bit_field,m,dc->fofs);
+			&mx_n,&org,dim_code,field,m,dc->fofs);
+		vecset_dim_code_index(n,field,0);
+		d_f_ree(field);
 	}
 	else {
 		load_raw_matrix_node(&mx_n,&org,dim_code,0,m,dc->fofs);
@@ -1494,7 +1503,7 @@ err:
 */
 
 	finish_file_access(m,0);
-	return -1;
+	return ME_MATRIX_ERR;
 }
 
 
@@ -1627,11 +1636,11 @@ debug = 1;
 		ptr = (unsigned char*)(dc+1);
 		ptr = get_compressed_dim_code(ptr,
 				n->dim_code,m->p.dim);
-		rt = get_root64(&w->favt64_err,
+		rt = l_get_root64(&w->favt64_err,
 			w->pdb_fd,
 			w->subheader.node_root,
 			mx_dim_code_endian);
-		fn = favt64_alloc_node(
+		fn = l_favt64_alloc_node(
 			rt,
 			dc,ptr - (unsigned char*)dc);
 		if ( fn == 0 ) {
@@ -1639,7 +1648,7 @@ debug = 1;
 			finish_file_access(m,0);
 			return -1;
 		}
-		fn2 = favt64_insert(&w->favt64_err,
+		fn2 = l_favt64_insert(&w->favt64_err,
 			rt,
 			&rt->node,fn,
 			mx_dim_code_cmp,m);
@@ -1671,7 +1680,7 @@ MX_FILE_WORK * w;
 	w = m->file_work;
 	w->subheader.flags &= ~MXF_WRITE;
 	save_subheader(m,1);
-	close_filespace64(w->pdb_fd);
+	l_close_filespace64(w->pdb_fd);
 	mx_open_files_cnt --;
 	call_unlock(w->lock_d);
 	d_f_ree(w);
@@ -1700,6 +1709,7 @@ matrix_standard_read_file(MATRIX_TOKEN * t)
 {
 int ret;
 
+//ss_printf("STANDARD READ FILE\n");
 	ret = load_matrix_node(t->process_node);
 
 	return ret;
@@ -1715,18 +1725,77 @@ int i;
 retry:
 	flush_all_dirty_file(m);
 	for ( i = 0 ; i < NHASH_SIZE ; i ++ ) {
-		for ( n = m->node_hash[i] ; n ; n = n->nh_next )
-			if ( n->fofs == 0 && n->status < MS_OK ) {
+		for ( n = m->node_hash[i] ; n ; n = n->nh_next ) {
+			if ( n->dirty_file_time || n->status < MS_OK ) {
 				finish_file_access_with_wait(m,(int)n);
 				if ( start_file_access(m) < 0 )
 					return -1;
 				goto retry;
 			}
+		}
 	}
 	return 0;
 }
 
 
+int
+_mx_scale_of_dim_code_func(FAVT64_NODE * a,void*wk)
+{
+FAVT64_NODE ** ap;
+	ap = (FAVT64_NODE**)wk;
+	*ap = a;
+	return 1;
+}
+
+int
+_mx_scale_of_dim_code(INTEGER64 * start,INTEGER64 * last,MATRIX * m)
+{
+int err;
+FAVT64_ROOT * rt;
+FAVT64_NODE * ret_a;
+MX_FILE_WORK * w;
+MX_DIM_CODE *dc;
+	w = m->file_work;
+	rt = l_get_root64(&w->favt64_err,
+		w->pdb_fd,
+		w->subheader.node_root,
+		mx_dim_code_endian);
+
+	ret_a = 0;
+	l_favt64_trace_from_small(&err,rt,l_root_node64(&w->favt64_err,rt),
+			_mx_scale_of_dim_code_func,(void*)&ret_a);
+	if ( ret_a == 0 )
+		return -1;
+	dc = ret_a->data;
+	get_uncompressed_dim_code(start,(unsigned char*)(dc+1));
+
+	ret_a = 0;
+	l_favt64_trace_from_large(&err,rt,l_root_node64(&w->favt64_err,rt),
+			_mx_scale_of_dim_code_func,(void*)&ret_a);
+	if ( ret_a == 0 )
+		return -1;
+	dc = ret_a->data;
+	get_uncompressed_dim_code(last,(unsigned char*)(dc+1));
+	return 0;
+}
+
+
+int
+mx_scale_of_dim_code(INTEGER64 * start,INTEGER64 * last,MATRIX * m)
+{
+int ret;
+	if ( start_file_access(m) < 0 )
+		return 0;
+	ret = -2;
+	if ( _mx_file_sync_create_node(m) < 0 )
+		goto end;
+	ret = _mx_scale_of_dim_code(start,last,m);
+end:
+	finish_file_access(m,0);
+	return ret;
+}
+
+
 MX_DIM_CODE_LIST *
 _mx_search_level_node(MATRIX * m,INTEGER64 * last_dc,int limit)
 {
@@ -1759,14 +1828,14 @@ int len;
 	w = m->file_work;
 
 
-	rt = get_root64(&w->favt64_err,
+	rt = l_get_root64(&w->favt64_err,
 		w->pdb_fd,
 		w->subheader.node_root,
 		mx_dim_code_endian);
 
-	bl = favt64_bound_search(
+	bl = l_favt64_bound_search(
 		&err,rt,
-		root_node64(&w->favt64_err,rt),
+		l_root_node64(&w->favt64_err,rt),
 		ldc_c,max_c,limit,
 		mx_dim_code_cmp,m);
 
