@@ -3007,7 +3007,7 @@ void
 set_mode_cals(MATRIX * mtx)
 {
 	save_mode_cal(mtx,MI_MODE_SERVER,mcd_server,default_pri);
-	save_mode_cal(mtx,MI_MODE_CRIENT,mcd_client,default_pri);
+	save_mode_cal(mtx,MI_MODE_CLIENT,mcd_client,default_pri);
 }
 
 
