@@ -593,11 +593,11 @@ int length, result;
 	new_tick((void(*)(int))open_timeout,-30,(int)con);
 	if ( scan_HTTP(&info,con,0) < 0 ) {
 		*cerr = ESYS_CTIMEOUT;
-		del_tick_with_data(open_timeout,(int)con);
+		del_tick_with_data((void(*)(int))open_timeout,(int)con);
 		s_close(con);
 		return 0;
 	}
-	del_tick_with_data(open_timeout,(int)con);
+	del_tick_with_data((void(*)(int))open_timeout,(int)con);
 	if ( info.err != 200 ) {
 		dont_keep_alive_mode = 1;
 		free_HTTP_info(&info);
@@ -691,7 +691,7 @@ int length, result;
 			chunk_read_end(con);
 		s_close(con);
 	}
-	create_task(XLoHTTP_task,(int)ret->xoh.info,PRI_WRITE_BUF);
+	create_task((void(*)(TKEY))XLoHTTP_task,(int)ret->xoh.info,PRI_WRITE_BUF);
 	lock_task(stream_lock);
 	_s_open(ret,O_RDWR);
 	unlock_task(stream_lock,"s_connect_XLoHTTP");
