@@ -64,6 +64,6 @@ timeout_exit(int limit,int force_limit,int (*sync_func)())
 	_limit = limit;
 	_force_limit = force_limit;
 	_sync_func = sync_func;
-	new_tick(exit_tick,-limit*0.9,0);
+	new_tick((void(*)(int))exit_tick,-limit*0.9,0);
 }
 
