@@ -1,4 +1,4 @@
-/* ver.B.b14(BLAZE) */
+/* ver.B.b16.02(BLAZE) */
 
 
 #include "version.h"
@@ -8,8 +8,8 @@ VERSION ap_version = {
 	"AP.code",
 	"nig2svg",
 	"(C) 2000-2007 Hirohisa Mori",
-	"ver.B.b14(BLAZE)",
-	2007,2,27,
+	"ver.B.b16.02(BLAZE)",
+	2007,5,27,
 	0,
 	"nigmas to svg format converter ",
 };
