@@ -1,4 +1,4 @@
-/* ver.B.b14.02(BLAZE) */
+/* ver.B.b16.03(BLAZE) */
 
 
 #include "version.h"
@@ -8,9 +8,9 @@ VERSION ap_version = {
 	"AP.code",
 	"gbmx",
 	"(C) 2000-2007 Hirohisa Mori",
-	"ver.B.b14.02(BLAZE)",
-	2007,2,27,
+	"ver.B.b16.03(BLAZE)",
+	2007,5,30,
 	0,
-	"GB r64/cr agent ../../src/gbs/lib/mx/gmxScan.c",
+	"GB r64/cr agent ../../src/gbs/lib/mx/gmxCopy.c",
 };
 
