@@ -1,4 +1,4 @@
-/* ver.B.b14(BLAZE) */
+/* ver.B.b16.03(BLAZE) */
 
 
 #include "version.h"
@@ -8,8 +8,8 @@ VERSION ap_version = {
 	"AP.code",
 	"ppm2r64",
 	"(C) 2000-2007 Hirohisa Mori",
-	"ver.B.b14(BLAZE)",
-	2007,2,10,
+	"ver.B.b16.03(BLAZE)",
+	2007,5,30,
 	0,
 	"ppm to r64/cr format converter ",
 };
