@@ -1,4 +1,4 @@
-/* ver.B.b14(BLAZE) */
+/* ver.B.b16.03(BLAZE) */
 
 
 #include "version.h"
@@ -7,9 +7,9 @@
 VERSION machine_code_version = {
 	"AP.code",
 	"cosmos",
-	"(C) 2000-2007 Hirohisa Mori",
-	"ver.B.b14(BLAZE)",
-	2007,2,27,
+	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
+	"ver.B.b16.03(BLAZE)",
+	2007,5,31,
 	0,
 	"GLOBALBASE client ",
 };
