@@ -272,6 +272,7 @@ VTreeNode * node1, * node2;
 L_CHAR null_ch = 0;
 L_CHAR edit_ch[2] = {'*',0};
 L_CHAR null_ch_2[2] = {' ',0};
+
 	node1 = tv->get_row((void*)key);
 	node2 = new VTreeNode(tv->get_n_cols());
 	node2->key = (void*)(unsigned int)key;
@@ -1046,6 +1047,9 @@ DIALOG_IO io;
 			if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#warpmenu")) == 0 &&
 				wpm_w.sts.wp_configure )
 				io.msg[0] = wpm_w.sts.wp_configure;
+			else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#iwp")) == 0 &&
+				wpm_w.sts.wp_configure )
+				io.msg[0] = wpm_w.sts.wp_configure;
 			else	io.msg[0] = wpm_w.sts.loading_target;
 			io.ret = DIO_NONE;
 			win = get_window_object(this);
@@ -1065,20 +1069,15 @@ DIALOG_IO io;
 	goto next;
 save:
 	__wpe_save();
-/*
-	if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#warpmenu")) == 0 ) {
-		wpm = _copyout_wpm_ext_list(&wpm_w.wpm_ext,0,0x7fffffff);
-		VgbFlame_set_wpm(wpm,2);
-		wpm_w.dirty_flag = 0;
-	}
-*/	
+
 next:
 	if ( win_close_handler ) {
 		(*win_close_handler)(object,win_close_arg,sys_arg);
 	}
 	else {
 		win = get_window_object(this);
-		win->destroy();
+		if ( win )
+			win->destroy();
 	}
 }
 
@@ -1313,6 +1312,41 @@ WARP_POINT_MENU_EXT ** v_ret;
 	VM_OP_END
 }
 
+
+void
+VgbWPMenuEdit::_set_iwp()
+{
+WARP_POINT_MENU * wpm;
+int len;
+VBackColorView ** bcl;
+
+	_VM_OP_START_VOID
+	bcl = wpm_w.xltv_obj->get_selected_bc_list(GST_LIST,&len);
+	wpm = _get_selected_wpm(wpm_w.xltv_obj,&wpm_w.wpm_ext,VMT_COPY,bcl,len);
+	if ( wpm == 0 ) {
+		VM_OP_END
+		return;
+	}
+	VM_OP_END
+	if ( wpm->next ) {
+		free_wpm(wpm->next);
+		wpm->next = 0;
+	}
+	VgbFlame_set_wpm(wpm,GET_WPM_IWP);
+	return;
+}
+
+V_CALLBACK_D(VgbWPMenuEdit::__set_iwp)
+{
+VgbWPMenuEdit * obj;
+VMenuItem * item;
+	item = static_cast<VMenuItem*>(user_arg);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	obj = (VgbWPMenuEdit*)item->get_user_work();
+	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	obj->_set_iwp();
+}
+
 int
 VgbWPMenuEdit::_xltv_focus_handler_obey_edit(
 	int event_type,
@@ -1419,6 +1453,9 @@ retry:
 	if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#warpmenu")) == 0 &&
 		wpm_w.sts.wp_configure )
 		io.msg[0] = wpm_w.sts.wp_configure;
+	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#iwp")) == 0 &&
+		wpm_w.sts.wp_configure )
+		io.msg[0] = wpm_w.sts.wp_configure;
 	else	io.msg[0] = wpm_w.sts.loading_target;
 	io.ret = DIO_NONE;
 	win = get_window_object(this);
@@ -1433,6 +1470,7 @@ retry:
 		data = convert_code(data,utf8_cm.main_code,0);
 		free_wpm(wp);
 		filename = get_machine_filename_string(io.ret_msg[0]);
+ss_printf("SAVE %s\n",filename);
 		st = s_open_file(filename,O_RDWR|O_CREAT|O_TRUNC,0644);
 		if ( st == 0 ) {
 			io.msg[0] = io.ret_msg[0];
@@ -1484,6 +1522,7 @@ XL_SEXP * r;
 	if ( io.ret == DIO_OK ) {
 		gc_push(0,0,"");
 		if ( wpm_w.sts.open_func ) {
+ss_printf("OEPN ==== %ls %ls\n",wpm_w.sts.open_func,io.ret_msg[0]);
 			r = eval(vobj_env,List(get_symbol(wpm_w.sts.open_func),
 					get_string(io.ret_msg[0]),
 					-1));
@@ -1583,7 +1622,6 @@ VObjectStatus v_sts;
 				print_sexp(st,data,PF_XML|PF_INDENT);
 				s_printf(st,"\n");
 				s_close(st);
-				d_f_ree(io.ret_msg[0]);
 			}
 			gc_pop(0,0);
 		}
@@ -1591,7 +1629,11 @@ VObjectStatus v_sts;
 	}
 	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#warpmenu")) == 0 ) {
 		wpm = _copyout_wpm_ext_list(&wpm_w.wpm_ext,0,0x7fffffff);
-		VgbFlame_set_wpm(wpm,2);
+		VgbFlame_set_wpm(wpm,GET_WPM_WARPMENU);
+	}
+	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#iwp")) == 0 ) {
+		wpm = _copyout_wpm_ext_list(&wpm_w.wpm_ext,0,0x7fffffff);
+		VgbFlame_set_wpm(wpm,GET_WPM_IWP);
 	}
 	else {
 		wpm = _copyout_wpm_ext_list(&wpm_w.wpm_ext,0,0x7fffffff);
@@ -1636,24 +1678,24 @@ VgbWPMenuEdit::_finish_edit_wpm(int flag)
 {
 VObjectStatus _sts;
 	_VM_OP_START_VOID
-ss_printf("FINISH TEXT-1\n");
+ss_printf("FINISH TEXT-1 %i\n",get_tid());
 	if ( wpm_w.edit_wpm == 0 )
 		goto end;
-ss_printf("FINISH TEXT-2\n");
+ss_printf("FINISH TEXT-2 %i\n",get_tid());
 	wpm_w.edit_wpm->main_text->get_status(&_sts,VSF_DESC|VSF_FOCUS);
 	if ( flag && _sts.focused == 1 )
 		goto end;
-ss_printf("FINISH TEXT-3\n");
+ss_printf("FINISH TEXT-3 %i\n",get_tid());
 	if ( l_strcmp((L_CHAR*)_sts.descriptor,wpm_w.edit_wpm->wpm->name) )
 		_set_dirty_flag();
 	d_f_ree(wpm_w.edit_wpm->wpm->name);
 	wpm_w.edit_wpm->wpm->name = ll_copy_str((L_CHAR*)_sts.descriptor);
 	_sts.value = 0;
-ss_printf("FINISH TEXT-4\n");
+ss_printf("FINISH TEXT-4 %i\n",get_tid());
 	wpm_w.edit_wpm->main_text->set_status(&_sts,VSF_VALUE);
 	wpm_w.edit_wpm = 0;
 end:
-ss_printf("FINISH TEXT-5\n");
+ss_printf("FINISH TEXT-5 %i\n",get_tid());
 	VM_OP_END
 }
 
@@ -1708,7 +1750,6 @@ VObjectStatus _sts;
 	e = wpm_w.edit_wpm;
 	_sts.value = 1;
 	_sts.descriptor = wpm_w.edit_wpm->wpm->name;
-ss_printf("START EDIT\n");
 	e->main_text->set_status(&_sts,VSF_VALUE|VSF_DESC|VSF_FOCUS);
 end:
 	VM_OP_END
@@ -1760,9 +1801,19 @@ short modify[] = {
 			if ( event_type == FHT_CLICK_BC )
 				e->_finish_edit_wpm(0);
 			e->_set_tv_wpm_event();
+
+
+			win = get_window_object(e);
+			if ( win ) {
+				VCustomizedMenuBar::set_menu_func_que(win,VMT_SET_IWP,__set_iwp,(int)e);
+				VCustomizedMenuBar::set_menu_flag_que(win,VMT_SET_IWP,VMF_ENABLED);
+			}
 		}
 		else {
 			ret = 0;
+			win = get_window_object(e);
+			if ( win )
+				VCustomizedMenuBar::set_menu_flag_que(win,VMT_SET_IWP,0);
 		}
 
 		if ( VdataWPM::clipboard_available() )
@@ -1829,6 +1880,8 @@ int p;
 	}
 	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#warpmenu")) == 0 ) {
 	}
+	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#iwp")) == 0 ) {
+	}
 	else {
 
 		win = get_window_object(this);
@@ -1854,11 +1907,14 @@ STREAM * st;
 	}
 	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#warpmenu")) == 0 ) {
 		free_wpm(wpm_w.sts.menu);
-		wpm_w.sts.menu = VgbFlameStandard::get_wpm();
+		wpm_w.sts.menu = VgbFlameStandard::get_wpm(GET_WPM_WARPMENU);
+	}
+	else if ( l_strcmp(wpm_w.sts.loading_target,l_string(std_cm,"#iwp")) == 0 ) {
+		free_wpm(wpm_w.sts.menu);
+		wpm_w.sts.menu = VgbFlameStandard::get_wpm(GET_WPM_IWP);
 	}
 	else {
 		filename = get_machine_filename_string(wpm_w.sts.loading_target);
-
 		st = s_open_file(filename,O_RDONLY);
 		if ( st == 0 ) {
 		}
@@ -2789,17 +2845,16 @@ VdataWP::VdataWP(const XL_SEXP * s,int * erp,bool valid)
 	: VdataXL((char*)0,0,0)
 {
 WARP_POINT * q;
-VdataXL * xl;
+XL_SEXP * _s;
 	if ( !valid )
 		return;
 	vdata_type = &VIM_VdataWP;
-	xl = new VdataXL(s,&err);
-	if ( err < 0 ) {
-		if ( erp )
-			*erp = err;
-		return;
+	_s = (XL_SEXP *)s;
+	for ( ; get_type_sexp((XL_SEXP*)_s) == XLT_PAIR ; _s = car(_s) ) {
+		if ( get_type_sexp(car(_s)) == XLT_SYMBOL )
+			break;
 	}
-	q = sexp2wp(xl->get_VdataXL());
+	q = sexp2wp(_s);
 	if ( q == 0 ) {
 		err = -1;
 		if ( erp )
@@ -3067,6 +3122,7 @@ VdataWPM::VdataWPM(const XL_SEXP * s,int * erp,bool valid)
 {
 WARP_POINT_MENU * q;
 VdataXL * xl;
+XL_SEXP * _xl;
 	if ( !valid )
 		return;
 	vdata_type = &VIM_VdataWPM;
@@ -3076,7 +3132,13 @@ VdataXL * xl;
 			*erp = err;
 		return;
 	}
-	q = sexp2wpm(xl->get_VdataXL());
+	_xl = xl->get_VdataXL();
+	for ( ; get_type_sexp(_xl) == XLT_PAIR ; ) {
+		if ( get_type_sexp(car(_xl)) == XLT_PAIR )
+			_xl = car(_xl);
+		else	break;
+	}
+	q = sexp2wpm(_xl);
 	if ( q == 0 ) {
 		err = -1;
 		if ( erp )
@@ -3270,6 +3332,11 @@ WARP_POINT_MENU * m;
 			*erp = -1;
 		return 0;
 	}
+	if ( m->wp == 0 ) {
+		if ( erp )
+			*erp = -1;
+		return 0;
+	}
 	ret = rc_copy_warp_point(m->wp);
 	if ( erp )
 		*erp = 0;
