@@ -30,10 +30,12 @@ extern "C" {
 #include "lock_level.h"
 }
 
+/*
 typedef struct menu_lock_inheritance {
 	struct menu_lock_inheritance *	next;
 	int				tid;
 } MENU_LOCK_INHERITANCE;
+*/
 
 int	VMenuItem::cnt = 0;
 SEM _menu_lock;
@@ -43,11 +45,14 @@ int menu_lock_tid;
 char * menu_lock_file;
 int menu_unlock_line;
 char * menu_unlock_file;
+int inheritance_id;
 
 extern "C" {
 void (*ms_lock_func)(char *,int);
 void (*ms_unlock_func)();
 void (*ms_inheritance_func)(int,char*,int);
+
+int inheritance_mode;
 }
 
 
@@ -364,11 +369,11 @@ VMenuBar::VMenuBar(VMenuItem *items, int category, bool base)
 {
 	next = v_menu_bars;
 	v_menu_bars = this;
-
+/*
 ss_printf("IN MENU-BAR\n");
 items->debug_print(1);
 ss_printf("IN MENU-BAR-END\n");
-
+*/
 	if ( category == 0 )
 		init();
 }
@@ -646,8 +651,8 @@ VCustomizedMenuBar::menu_choosed(VMenuItem *item)
 			return true;
 	
 	if ( item && item->func ) {
-		item->i_tid = get_tid();
 		VCustomizedMenuBar::menu_lock(__FILE__,__LINE__);
+		item->i_tid = VCustomizedMenuBar::menu_lock_inheritance_from();
 		vq_insert_callback(window, item->func, item, 0, 0,0);
 		return true;
 	}
@@ -675,76 +680,95 @@ VCustomizedMenuBar::init_menu_lock()
 void 
 VCustomizedMenuBar::menu_lock(char * file,int line) {
 int tid;
-	if ( ms_lock_func ) {
-		(*ms_lock_func)(file,line);
-		return;
-	}
-	tid = get_tid();
 	lock_task(_menu_lock);
-	if ( menu_lock_tid && menu_lock_tid != tid ) {
-		for ( ; menu_lock_cnt != 0 ; ) {
-			sleep_task((int)&_menu_lock,_menu_lock);
-			lock_task(_menu_lock);
+	for ( ; inheritance_mode ; ) {
+		sleep_task((int)&inheritance_mode,_menu_lock);
+		lock_task(_menu_lock);
+	}
+	if ( ms_lock_func ) {
+		unlock_task(_menu_lock,"menu_lock");
+		(*ms_lock_func)(file,line);
+	}
+	else {
+		tid = get_tid();
+		if ( menu_lock_tid && menu_lock_tid != tid ) {
+			for ( ; menu_lock_cnt != 0 ; ) {
+				sleep_task((int)&_menu_lock,_menu_lock);
+				lock_task(_menu_lock);
+			}
 		}
+		menu_lock_cnt ++;
+		menu_lock_tid = tid;
+		menu_lock_file = file;
+		menu_lock_line = line;
+		unlock_task(_menu_lock,"menu_lock");
 	}
-	menu_lock_cnt ++;
-	menu_lock_tid = tid;
-	menu_lock_file = file;
-	menu_lock_line = line;
 /*
-printf("menu_lock %s %i %i %i\n",menu_lock_file,menu_lock_line,menu_lock_tid,menu_lock_cnt);
+printf("menu_lock %s %i\n",file,line);
 */
-	unlock_task(_menu_lock,"menu_lock");
-
 }
 
 void 
 VCustomizedMenuBar::menu_unlock(char * file,int line) {
 int tid;
-	if ( ms_unlock_func ) {
-		(*ms_unlock_func)();
-		return;
-	}
-	tid = get_tid();
 	lock_task(_menu_lock);
-	if  ( menu_lock_tid != tid )
-		er_panic("menu_unlock(1)");
-	menu_lock_cnt --;
-	if ( menu_lock_cnt == 0 ) {
-		wakeup_task((int)&_menu_lock);
-		menu_lock_tid = 0;
+	if ( ms_unlock_func ) {
+		unlock_task(_menu_lock,"menu_unlock");
+		(*ms_unlock_func)();
+	}
+	else {
+		tid = get_tid();
+		if  ( menu_lock_tid != tid )
+			er_panic("menu_unlock(1)");
+		menu_lock_cnt --;
+		if ( menu_lock_cnt == 0 ) {
+			wakeup_task((int)&_menu_lock);
+			menu_lock_tid = 0;
+		}
+		menu_unlock_file = file;
+		menu_unlock_line = line;
+		unlock_task(_menu_lock,"menu_unlock");
 	}
 /*
-printf("menu_unlock %s %i %i %i\n",menu_lock_file,menu_lock_line,menu_lock_tid,menu_lock_cnt);
+printf("menu_unlock %s %i\n",file,line);
 */
-	menu_unlock_file = file;
-	menu_unlock_line = line;
-	unlock_task(_menu_lock,"menu_unlock");
+}
+
+int
+VCustomizedMenuBar::menu_lock_inheritance_from()
+{
+int ret;
+	lock_task(_menu_lock);
+	if ( inheritance_mode )
+		er_panic("menu_lock_inheritance_from");
+	if ( inheritance_id <= 0 )
+		inheritance_id = 1;
+	else	inheritance_id ++;
+	ret = inheritance_mode = inheritance_id;
+	unlock_task(_menu_lock,"menu_lock_inheritance_from");
+	return ret;
 }
 
 void
 VCustomizedMenuBar::menu_lock_inheritance(int itid,char * file,int line)
 {
 int tid;
+	lock_task(_menu_lock);
+	if ( inheritance_mode == 0 )
+		er_panic("menu_lock_inheritance");
+	if ( itid != inheritance_mode )
+		er_panic("menu_lock_inheritance(2)");
+	inheritance_mode = 0;
 	if ( ms_unlock_func ) {
 		(*ms_inheritance_func)(itid,file,line);
-		return;
-	}
-	tid = get_tid();
-	lock_task(_menu_lock);
-	for ( ; menu_lock_tid && menu_lock_tid != itid ; ) {
-		sleep_task((int)&_menu_lock,_menu_lock);
-		lock_task(_menu_lock);
-	}
-	if ( menu_lock_tid == 0 ) {
-		menu_lock_cnt ++;
-		menu_lock_tid = tid;
-		menu_lock_file = file;
-		menu_lock_line = line;
 	}
 	else {
+		tid = get_tid();
+		if ( menu_lock_tid == 0 )
+			er_panic("menu_lock_inheritance(3)");
 		menu_lock_tid = tid;
 	}
+	wakeup_task((int)&inheritance_mode);
 	unlock_task(_menu_lock,"menu_unlock");
 }
 
