@@ -90,7 +90,7 @@ test2_task()
 
 V_CALLBACK_D(test2)
 {
-	create_task(test2_task,0,5);
+	create_task((void(*)(TKEY))test2_task,0,5);
 }
 
 void make_img3(VImage*, int);
@@ -121,7 +121,7 @@ test3_task()
 void
 test3()
 {
-	create_task(test3_task,0,5);
+	create_task((void(*)(TKEY))test3_task,0,5);
 }
 
 V_CALLBACK_D(menu_test_1)
