@@ -209,7 +209,7 @@ L_CHAR * site;
 }
 
 void
-set_close_func(XL_FILE * f,void (*func)(),void * work)
+set_close_func(XL_FILE * f,void (*func)(int,void*),void * work)
 {
 	f->close_work = work;
 	f->close_func = func;
