@@ -83,7 +83,7 @@ void _insert_ss(STREAM *s,unsigned int ip,XL_INTERPRETER * xli,PERMISSION_LIST *
 STREAM_STOCK * _delete_ss();
 void sslist_scan();
 void insert_ss(STREAM * s,unsigned int ip,XL_INTERPRETER * xli,PERMISSION_LIST * pl);
-STREAM * delete_ss();
+STREAM_STOCK * delete_ss();
 void timeout_stream(STREAM * s);
 XoH_LIST *get_recv_seq_list(XoH_ENTRY * e);
 int _empty_reply(XoH_ENTRY * e,unsigned int now);
@@ -309,7 +309,7 @@ insert_ss(STREAM * s,unsigned int ip,XL_INTERPRETER * xli,PERMISSION_LIST * pl)
 	unlock_task(XoH_lock,"insert_ss");
 }
 
-STREAM *
+STREAM_STOCK *
 delete_ss()
 {
 STREAM_STOCK * ret;
@@ -348,7 +348,7 @@ HTTP_INFO o_info;
 	new_tick((void(*)(int))timeout_stream,
 			-DEL_TIMEOUT1,(int)lst->con);
 	if ( scan_HTTP(&lst->info,key->s,1) < 0 ) {
-		del_tick_with_data(timeout_stream,(int)lst->con);
+		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
 		d_f_ree(lst);
 		s_close(key->s);
 		return -1;
@@ -357,7 +357,7 @@ HTTP_INFO o_info;
 ss_printf("HTTP %s %s\n",lst->info.method,lst->info.dir);
 */
 	if ( strcmp(lst->info.method,"GET") == 0 ) {
-		del_tick_with_data(timeout_stream,(int)lst->con);
+		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
 		ret = exec_url(&lst->info,key->s);
 		if ( ret <= 1 )
 			return ret;
@@ -374,27 +374,27 @@ ss_printf("HTTP %s %s\n",lst->info.method,lst->info.dir);
 		}
 	}
 	else {
-		del_tick_with_data(timeout_stream,(int)lst->con);
+		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
 		ret = exec_url(&lst->info,key->s);
 		if ( ret <= 1 )
 			return ret;
 	}
 	if ( lst->info.content_length >= 0 && 
 			lst->info.content_length < sizeof(lst->h) ) {
-		del_tick_with_data(timeout_stream,(int)lst->con);
+		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
 		free_HTTP_info(&lst->info);
 		d_f_ree(lst);
 		s_close(key->s);
 		return -1;
 	}
 	if ( en_do(&ret_len,s_read,key->s,&lst->h,sizeof(lst->h)) <= 0 ) {
-		del_tick_with_data(timeout_stream,(int)lst->con);
+		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
 		free_HTTP_info(&lst->info);
 		d_f_ree(lst);
 		s_close(key->s);
 		return -1;
 	}
-	del_tick_with_data(timeout_stream,(int)lst->con);
+	del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
 
 	change_endian_XLoHTTP_HEADER(&lst->h);
 	lst->h.sum = XoH_checksum(&lst->h);
@@ -681,10 +681,10 @@ int len;
 		case S_COPY_TO_STREAM_SRC_ERR:
 			break;
 		case S_COPY_TO_STREAM_DEST_ERR:
-			del_tick_with_data(timeout_stream,(int)con);
+			del_tick_with_data((void(*)(int))timeout_stream,(int)con);
 			goto last;
 		}
-		del_tick_with_data(timeout_stream,(int)con);
+		del_tick_with_data((void(*)(int))timeout_stream,(int)con);
 	next:
 		lock_task(XoH_lock);
 		e->recv_seq ++;
