@@ -68,7 +68,7 @@ init_http_agent()
 
 	ha_lock = new_lock(LL_HTTP_AGENT);
 //	create_task(exec_url_task,PRI_USER_INTERFACE,0);
-	new_tick(tick_http_agent,10,10);
+	new_tick((void(*)(int))tick_http_agent,10,10);
 }
 
 void
