@@ -193,7 +193,7 @@ void remote_session_tick();
 			continue;
 		}
 		if ( resp->s_id )
-			new_tick(remote_session_tick,0,(int)resp->s_session);
+			new_tick((void(*)(int))remote_session_tick,0,(int)resp->s_session);
 		new_tick(remote_gc_tick,0,(int)resp);
 		*rpp = resp->next;
 		if ( xli->result_head == 0 )
@@ -257,6 +257,7 @@ init_interpreter()
 
 	init_http_agent(); 
 
+	init_authentificaition(gblisp_top_env0);
 }
 
 void
@@ -351,6 +352,7 @@ LOCK_FUNCTION_TYPE ** wp, * wpp;
 	lock_task(xli_lock);
 	if ( lock_function == 0 )
 		goto end;
+	memset(&w,0,sizeof(w));
 	w.xli = _get_my_xli();
 	if ( w.xli->flags & XIF_LOCK_DISE )
 		goto end;
@@ -1068,6 +1070,7 @@ int pri;
 	xli->accept_lock = 0;
 	xli->accept_last_dec = get_xltime();
 
+	xli->auth_c_set = new_auth_connection_set(xli);
 
 	if ( xli->a_type != XLA_SELF && main_interpreter_flag == 0 ) {
 		main_interpreter = xli;
@@ -1235,6 +1238,15 @@ delay_t_check_xli(SYS_QUEUE * q,DELAY_QUE_T * n,XL_INTERPRETER * xli)
 	return -1;
 }
 
+
+void
+free_auth_tick(int data)
+{
+AUTH_CONNECTION_SET * set;
+	set = (AUTH_CONNECTION_SET*)data;
+	free_auth_connection_set(set);
+}
+
 void
 _close_xl_interpreter(XL_INTERPRETER * xli)
 {
@@ -1279,6 +1291,7 @@ STREAM * s_out,* s_err;
 		d_f_ree(xli->output_file_name);
 	if ( xli->error_file_name )
 		d_f_ree(xli->error_file_name);
+	new_tick(free_auth_tick,0,(int)xli->auth_c_set);
 
 	key = xli->id%INTERPRETER_HASH_SIZE;
 	for ( xlip = &interpreter_hash[key];
@@ -1594,7 +1607,7 @@ printf("BUSY 1\n");
 		new_tick((void(*)(int))accept_thread_tick,
 			 -xli->accept_interval,(int)key->s);
 		if ( s_read(key->s,&ch,1) < 1 ) {
-			del_tick_with_data(accept_thread_tick,(int)key->s);
+			del_tick_with_data((void(*)(int))accept_thread_tick,(int)key->s);
 			xli->accept_interval *= 2;
 			if ( xli->accept_interval > ACCEPT_RET_MAX )
 				xli->accept_interval = ACCEPT_RET_MAX;
@@ -1603,7 +1616,7 @@ printf("BUSY 1\n");
 			d_f_ree(key);
 			continue;
 		}
-		del_tick_with_data(accept_thread_tick,(int)key->s);
+		del_tick_with_data((void(*)(int))accept_thread_tick,(int)key->s);
 		next_interval = get_xltime() - invoke_time;
 		if ( 2*next_interval < xli->accept_interval &&
 			get_xltime() - xli->accept_last_dec
@@ -2550,9 +2563,10 @@ int tid;
 	if ( xli->mode != XIM_RUN )
 		return;
 	if ( xli->silent_timeout < 0 )
-		return;
+		goto connection_timeout;
 	else if ( xli->silent_cnt >= xli->silent_timeout )
 		goto xli_break;
+connection_timeout:
 	if ( xli->connection_timeout < 0 )
 		return;
 	if ( xli->connection_cnt < xli->connection_timeout )
