@@ -94,7 +94,7 @@ SYM_DATA_TYPE sym_data_list[] = {
 #define FS_EQU		2
 #define FS_LARGE	3
 #define FS_EQU_LARGE	4
-#define FS_SYMBOL	5
+#define FS_SYM		5
 
 char *fs_table[] = {
 	0,
@@ -579,9 +579,9 @@ get_data_info(LOG_NODE_DATA * lnd,L_CHAR * sym)
 int f;
 char buf[20];
 	f = get_log_cond_symbol(sym);
-	if ( f < FS_SYMBOL )
+	if ( f < FS_SYM )
 		er_panic("get_data_info");
-	f = f-FS_SYMBOL;
+	f = f-FS_SYM;
 	if ( LOG_NODE_DATA_INT_PATTERN & (1<<f) ) {
 		sprintf(buf,"%i",lnd->_int[f]);
 		return nl_copy_str(std_cm,buf);
@@ -1130,7 +1130,7 @@ L_CHAR * tmp;
 			goto err;
 		if ( f == FS_ASTARISK )
 			goto back_ASTARISK;
-		if ( f < FS_SYMBOL )
+		if ( f < FS_SYM )
 			return get_error(
 				lst->h.file,
 				lst->h.line,
@@ -1209,7 +1209,7 @@ back_ASTARISK_DATA_EQU:
 	if ( get_type(el) != XLT_SYMBOL )
 		goto err;
 	f = get_log_cond_symbol(el->symbol.data);
-	if ( f < FS_SYMBOL )
+	if ( f < FS_SYM )
 		goto err;
 	field = f;
 	goto finish;
@@ -1219,7 +1219,7 @@ equ_DATA_EQU:
 	if ( get_type(el) != XLT_SYMBOL )
 		goto err;
 	f = get_log_cond_symbol(el->symbol.data);
-	if ( f < FS_SYMBOL )
+	if ( f < FS_SYM )
 		goto err;
 	field = f;
 	goto finish;
@@ -1239,7 +1239,7 @@ flont_DATA_ASTARISK_EQU:
 	if ( get_type(el) != XLT_SYMBOL )
 		goto err;
 	f = get_log_cond_symbol(el->symbol.data);
-	if ( f < FS_SYMBOL )
+	if ( f < FS_SYM )
 		goto err;
 	field = f;
 	goto finish;
@@ -1249,7 +1249,7 @@ bound_DATA_LARGE:
 	if ( get_type(el) != XLT_SYMBOL )
 		goto err;
 	f = get_log_cond_symbol(el->symbol.data);
-	if ( f < FS_SYMBOL )
+	if ( f < FS_SYM )
 		goto err;
 	field = f;
 	goto bound_DATA_LARGE_FIELD;
@@ -1329,19 +1329,19 @@ finish:
 			goto err;
 		}
 	}
-	lc->op[field-FS_SYMBOL] = op;
+	lc->op[field-FS_SYM] = op;
 	switch ( get_type(data1) ) {
 	case XLT_INTEGER:
-		lc->low._int[field-FS_SYMBOL] = data1->integer.data;
+		lc->low._int[field-FS_SYM] = data1->integer.data;
 		break;
 	case XLT_STRING:
-		lc->low._chr[field-FS_SYMBOL] = ll_copy_str(data1->string.data);
+		lc->low._chr[field-FS_SYM] = ll_copy_str(data1->string.data);
 		break;
 	case XLT_NULL:
-		if ( LOG_NODE_DATA_INT_PATTERN & (field-FS_SYMBOL) )
-			lc->low._int[field-FS_SYMBOL] = 0;
+		if ( LOG_NODE_DATA_INT_PATTERN & (field-FS_SYM) )
+			lc->low._int[field-FS_SYM] = 0;
 		else {
-			lc->high._chr[field-FS_SYMBOL] = tmp = 
+			lc->high._chr[field-FS_SYM] = tmp = 
 				d_alloc(sizeof(L_CHAR));
 			tmp[0] = 0;
 		}
@@ -1349,16 +1349,16 @@ finish:
 	}
 	switch ( get_type(data2) ) {
 	case XLT_INTEGER:
-		lc->high._int[field-FS_SYMBOL] = data2->integer.data;
+		lc->high._int[field-FS_SYM] = data2->integer.data;
 		break;
 	case XLT_STRING:
-		lc->high._chr[field-FS_SYMBOL] = ll_copy_str(data2->string.data);
+		lc->high._chr[field-FS_SYM] = ll_copy_str(data2->string.data);
 		break;
 	case XLT_NULL:
-		if ( LOG_NODE_DATA_INT_PATTERN & (field-FS_SYMBOL) )
-			lc->high._int[field-FS_SYMBOL] = 0x7fffffff;
+		if ( LOG_NODE_DATA_INT_PATTERN & (field-FS_SYM) )
+			lc->high._int[field-FS_SYM] = 0x7fffffff;
 		else {
-			lc->high._chr[field-FS_SYMBOL] = tmp = 
+			lc->high._chr[field-FS_SYM] = tmp = 
 				d_alloc(2*sizeof(L_CHAR));
 			tmp[0] = 0x7fffffff;
 			tmp[1] = 0;
@@ -1559,12 +1559,15 @@ int
 xl_log_vprintf(
 	int level,
 	int layer,
-	LOG_NODE_DATA * opt,
+	void * _opt,
 	char * fmt,
 	va_list p)
 {
 LOG_NODE * ln,* ln2;
 STREAM * st;
+LOG_NODE_DATA * opt;
+
+  	opt = (LOG_NODE_DATA*)_opt;
 
 	st = s_open_string_write(&int_cm);
 
