@@ -238,8 +238,8 @@ void
 init_session_xlp()
 {
 	session_lock = new_lock(LL_SESSION);
-	new_tick(session_tick,CHECK_INTERVAL,0);
-	create_task(agent_timeout_task,0,PRI_AGENT);
+	new_tick((void(*)(int))session_tick,CHECK_INTERVAL,0);
+	create_task((void(*)(TKEY))agent_timeout_task,0,PRI_AGENT);
 }
 
 void
@@ -1208,9 +1208,12 @@ int _ret;
 
 	*retp = 0;
 	retry_cnt = 0;
+	if ( u->resource == 0 )
+		goto inv;
 	for ( p = l_strlen(u->resource)-1 ; p >= 0 ; p -- )
 		if ( u->resource[p] == '.' )
 			goto next;
+inv:
 	*retp = get_error(
 		0,
 		0,
