@@ -72,14 +72,38 @@ _search_remote_version(URL * u,char * layer);
 VERSION *
 _insert_remote_version(VERSION * v,URL * u,char * layer);
 
-int open_session_xlp();
-void close_session_xlp();
-XL_SEXP * remote_session_xlp();
+int open_session_xlp(int);
+void close_session_xlp(int);
+XL_SEXP *
+remote_session_xlp(
+	XLISP_ENV * env,
+	int id,
+	URL * u,
+	L_CHAR * _a_agent,
+	L_CHAR * _a_login_mode,
+	L_CHAR * _a_center_cmd,
+	XL_SEXP * cmd,
+	XL_FILE * f,
+	int ln,
+	int session_lock_enable,
+	REMOTE_SESSION_OPT * opt);
 VERSION * get_remote_version_xlp(int id,URL * u,char * layer);
 
-int open_session_http();
-void close_session_http();
-XL_SEXP * remote_session_http();
+int open_session_http(int);
+void close_session_http(int);
+XL_SEXP *
+remote_session_http(
+	XLISP_ENV * env,
+	int id,
+	URL * u,
+	L_CHAR * _a_agent,
+	L_CHAR * _a_login_mode,
+	L_CHAR * _a_center_cmd,
+	XL_SEXP * cmd,
+	XL_FILE * f,
+	int ln,
+	int session_lock_enable,
+	REMOTE_SESSION_OPT * opt);
 
 extern SEM	session_lock;
 int	session_sw_id;
